PRAGMA foreign_keys=OFF;
BEGIN TRANSACTION;
CREATE TABLE experiment_run (
      run_id INTEGER NOT NULL PRIMARY KEY AUTOINCREMENT,
      created TEXT NOT NULL,
      modified TEXT NOT NULL,
      start INTEGER NOT NULL,
      finish INTEGER,
      chunk_unit TEXT NOT NULL,
      chunk_size INTEGER NOT NULL,
      completed INTEGER NOT NULL,
      total INTEGER NOT NULL,
      failed INTEGER NOT NULL,
      queuing INTEGER NOT NULL,
      running INTEGER NOT NULL,
      submitted INTEGER NOT NULL,
      suspended INTEGER NOT NULL DEFAULT 0,
      metadata TEXT
      );
INSERT INTO experiment_run VALUES(1,'2023-09-29-14:21:45','2023-10-02-10:08:00',1695990105,1696234080,'month',4,0,8,0,0,0,0,0,'{"CONFIG": {"AUTOSUBMIT_VERSION": "4.0.0", "MAXWAITINGJOBS": 20, "TOTALJOBS": 20, "SAFETYSLEEPTIME": 10, "RETRIALS": 0}, "MAIL": {"NOTIFICATIONS": false, "TO": null}, "STORAGE": {"TYPE": "pkl", "COPY_REMOTE_LOGS": true}, "DEFAULT": {"EXPID": "a04c", "HPCARCH": "local", "CUSTOM_CONFIG": "/home/dbeltran/new_autosubmit/a01o/proj/git_project/as_conf"}, "EXPERIMENT": {"DATELIST": 20220401, "MEMBERS": "fc0", "CHUNKSIZEUNIT": "month", "CHUNKSIZE": 4, "NUMCHUNKS": 2, "CHUNKINI": "", "CALENDAR": "standard"}, "PROJECT": {"PROJECT_TYPE": "none", "PROJECT_DESTINATION": ""}, "GIT": {"PROJECT_ORIGIN": "", "PROJECT_BRANCH": "", "PROJECT_COMMIT": "", "PROJECT_SUBMODULES": "", "FETCH_SINGLE_BRANCH": true}, "SVN": {"PROJECT_URL": "", "PROJECT_REVISION": ""}, "LOCAL": {"PROJECT_PATH": ""}, "PROJECT_FILES": {"FILE_PROJECT_CONF": "", "FILE_JOBS_CONF": "", "JOB_SCRIPTS_TYPE": ""}, "RERUN": {"RERUN": false, "RERUN_JOBLIST": ""}, "JOBS": {"LOCAL_SETUP": {"FILE": "LOCAL_SETUP.sh", "PLATFORM": "LOCAL", "RUNNING": "once", "DEPENDENCIES": {}, "ADDITIONAL_FILES": []}, "REMOTE_SETUP": {"FILE": "REMOTE_SETUP.sh", "DEPENDENCIES": {"LOCAL_SETUP": {}}, "WALLCLOCK": "00:05", "RUNNING": "once", "ADDITIONAL_FILES": []}, "INI": {"FILE": "INI.sh", "DEPENDENCIES": {"REMOTE_SETUP": {}}, "RUNNING": "member", "WALLCLOCK": "00:05", "ADDITIONAL_FILES": []}, "SIM": {"FILE": "SIM.sh", "DEPENDENCIES": {"INI": {}, "SIM-1": {}}, "RUNNING": "chunk", "WALLCLOCK": "00:05", "ADDITIONAL_FILES": []}, "POST": {"FILE": "POST.sh", "DEPENDENCIES": {"SIM": {}}, "RUNNING": "once", "WALLCLOCK": "00:05", "ADDITIONAL_FILES": []}, "CLEAN": {"FILE": "CLEAN.sh", "DEPENDENCIES": {"POST": {}}, "RUNNING": "once", "WALLCLOCK": "00:05", "ADDITIONAL_FILES": []}, "TRANSFER": {"FILE": "TRANSFER.sh", "PLATFORM": "LOCAL", "DEPENDENCIES": {"CLEAN": {}}, "RUNNING": "member", "ADDITIONAL_FILES": []}}, "PLATFORMS": {"MARENOSTRUM4": {"TYPE": "slurm", "HOST": "mn1.bsc.es", "PROJECT": "bsc32", "USER": "bsc32xxx", "QUEUE": "debug", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": false, "MAX_WALLCLOCK": "48:00", "TEMP_DIR": ""}, "MARENOSTRUM_ARCHIVE": {"TYPE": "ps", "HOST": "dt02.bsc.es", "PROJECT": "bsc32", "USER": "bsc32xxx", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": false, "TEST_SUITE": false}, "TRANSFER_NODE": {"TYPE": "ps", "HOST": "dt01.bsc.es", "PROJECT": "bsc32", "USER": "bsc32xxx", "ADD_PROJECT_TO_HOST": false, "SCRATCH_DIR": "/gpfs/scratch"}, "TRANSFER_NODE_BSCEARTH000": {"TYPE": "ps", "HOST": "bscearth000", "USER": "dbeltran", "PROJECT": "Earth", "ADD_PROJECT_TO_HOST": false, "QUEUE": "serial", "SCRATCH_DIR": "/esarchive/scratch"}, "BSCEARTH000": {"TYPE": "ps", "HOST": "bscearth000", "USER": "dbeltran", "PROJECT": "Earth", "ADD_PROJECT_TO_HOST": false, "QUEUE": "serial", "SCRATCH_DIR": "/esarchive/scratch"}, "NORD3": {"TYPE": "SLURM", "HOST": "nord1.bsc.es", "PROJECT": "bsc32", "USER": "bsc32xxx", "QUEUE": "debug", "SCRATCH_DIR": "/gpfs/scratch", "MAX_WALLCLOCK": "48:00"}, "ECMWF-XC40": {"TYPE": "ecaccess", "VERSION": "pbs", "HOST": "cca", "USER": "c3d", "PROJECT": "spesiccf", "ADD_PROJECT_TO_HOST": false, "SCRATCH_DIR": "/scratch/ms", "QUEUE": "np", "SERIAL_QUEUE": "ns", "MAX_WALLCLOCK": "48:00"}}, "ROOTDIR": "/home/dbeltran/new_autosubmit/a01o", "PROJDIR": "/home/dbeltran/new_autosubmit/a01o/proj/project_files"}');
INSERT INTO experiment_run VALUES(2,'2023-10-02-10:08:00','2023-10-02-12:49:21',1696234080,1696243761,'month',4,0,8,0,0,0,0,0,'{"CONFIG": {"AUTOSUBMIT_VERSION": "4.0.95", "MAXWAITINGJOBS": 20, "TOTALJOBS": 20, "SAFETYSLEEPTIME": 10, "RETRIALS": 0}, "MAIL": {"NOTIFICATIONS": false, "TO": null}, "STORAGE": {"TYPE": "pkl", "COPY_REMOTE_LOGS": true}, "DEFAULT": {"EXPID": "a04c", "HPCARCH": "local", "CUSTOM_CONFIG": "/home/dbeltran/new_autosubmit/a01o/proj/git_project/as_conf"}, "EXPERIMENT": {"DATELIST": 20220401, "MEMBERS": "fc0", "CHUNKSIZEUNIT": "month", "CHUNKSIZE": 4, "NUMCHUNKS": 2, "CHUNKINI": "", "CALENDAR": "standard"}, "PROJECT": {"PROJECT_TYPE": "none", "PROJECT_DESTINATION": ""}, "GIT": {"PROJECT_ORIGIN": "", "PROJECT_BRANCH": "", "PROJECT_COMMIT": "", "PROJECT_SUBMODULES": "", "FETCH_SINGLE_BRANCH": true}, "SVN": {"PROJECT_URL": "", "PROJECT_REVISION": ""}, "LOCAL": {"PROJECT_PATH": ""}, "PROJECT_FILES": {"FILE_PROJECT_CONF": "", "FILE_JOBS_CONF": "", "JOB_SCRIPTS_TYPE": ""}, "RERUN": {"RERUN": false, "RERUN_JOBLIST": ""}, "JOBS": {"LOCAL_SETUP": {"FILE": "LOCAL_SETUP.sh", "PLATFORM": "LOCAL", "RUNNING": "once", "DEPENDENCIES": {}, "ADDITIONAL_FILES": []}, "REMOTE_SETUP": {"FILE": "REMOTE_SETUP.sh", "DEPENDENCIES": {"LOCAL_SETUP": {}}, "WALLCLOCK": "00:05", "RUNNING": "once", "ADDITIONAL_FILES": []}, "INI": {"FILE": "INI.sh", "DEPENDENCIES": {"REMOTE_SETUP": {}}, "RUNNING": "member", "WALLCLOCK": "00:05", "ADDITIONAL_FILES": []}, "SIM": {"FILE": "SIM.sh", "DEPENDENCIES": {"INI": {}, "SIM-1": {}}, "RUNNING": "chunk", "WALLCLOCK": "00:05", "ADDITIONAL_FILES": []}, "POST": {"FILE": "POST.sh", "DEPENDENCIES": {"SIM": {}}, "RUNNING": "once", "WALLCLOCK": "00:05", "ADDITIONAL_FILES": []}, "CLEAN": {"FILE": "CLEAN.sh", "DEPENDENCIES": {"POST": {}}, "RUNNING": "once", "WALLCLOCK": "00:05", "ADDITIONAL_FILES": []}, "TRANSFER": {"FILE": "TRANSFER.sh", "PLATFORM": "LOCAL", "DEPENDENCIES": {"CLEAN": {}}, "RUNNING": "member", "ADDITIONAL_FILES": []}}, "PLATFORMS": {"MARENOSTRUM4": {"TYPE": "slurm", "HOST": "mn1.bsc.es", "PROJECT": "bsc32", "USER": "bsc32xxx", "QUEUE": "debug", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": false, "MAX_WALLCLOCK": "48:00", "TEMP_DIR": ""}, "MARENOSTRUM_ARCHIVE": {"TYPE": "ps", "HOST": "dt02.bsc.es", "PROJECT": "bsc32", "USER": "bsc32xxx", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": false, "TEST_SUITE": false}, "TRANSFER_NODE": {"TYPE": "ps", "HOST": "dt01.bsc.es", "PROJECT": "bsc32", "USER": "bsc32xxx", "ADD_PROJECT_TO_HOST": false, "SCRATCH_DIR": "/gpfs/scratch"}, "TRANSFER_NODE_BSCEARTH000": {"TYPE": "ps", "HOST": "bscearth000", "USER": "dbeltran", "PROJECT": "Earth", "ADD_PROJECT_TO_HOST": false, "QUEUE": "serial", "SCRATCH_DIR": "/esarchive/scratch"}, "BSCEARTH000": {"TYPE": "ps", "HOST": "bscearth000", "USER": "dbeltran", "PROJECT": "Earth", "ADD_PROJECT_TO_HOST": false, "QUEUE": "serial", "SCRATCH_DIR": "/esarchive/scratch"}, "NORD3": {"TYPE": "SLURM", "HOST": "nord1.bsc.es", "PROJECT": "bsc32", "USER": "bsc32xxx", "QUEUE": "debug", "SCRATCH_DIR": "/gpfs/scratch", "MAX_WALLCLOCK": "48:00"}, "ECMWF-XC40": {"TYPE": "ecaccess", "VERSION": "pbs", "HOST": "cca", "USER": "c3d", "PROJECT": "spesiccf", "ADD_PROJECT_TO_HOST": false, "SCRATCH_DIR": "/scratch/ms", "QUEUE": "np", "SERIAL_QUEUE": "ns", "MAX_WALLCLOCK": "48:00"}}, "ROOTDIR": "/home/dbeltran/new_autosubmit/a01o", "PROJDIR": "/home/dbeltran/new_autosubmit/a01o/proj/project_files"}');
INSERT INTO experiment_run VALUES(3,'2023-10-02-12:49:21','2023-10-02-12:55:51',1696243761,1696244151,'month',4,0,10,0,0,0,0,0,'{"CONFIG": {"AUTOSUBMIT_VERSION": "4.0.95", "MAXWAITINGJOBS": 20, "TOTALJOBS": 20, "SAFETYSLEEPTIME": 10, "RETRIALS": 0}, "MAIL": {"NOTIFICATIONS": false, "TO": null}, "STORAGE": {"TYPE": "pkl", "COPY_REMOTE_LOGS": true}, "DEFAULT": {"EXPID": "a04c", "HPCARCH": "local", "CUSTOM_CONFIG": "/home/dbeltran/new_autosubmit/a01o/proj/git_project/as_conf"}, "EXPERIMENT": {"DATELIST": 20220401, "MEMBERS": "fc0", "CHUNKSIZEUNIT": "month", "CHUNKSIZE": 4, "NUMCHUNKS": 2, "CHUNKINI": "", "CALENDAR": "standard"}, "PROJECT": {"PROJECT_TYPE": "none", "PROJECT_DESTINATION": ""}, "GIT": {"PROJECT_ORIGIN": "", "PROJECT_BRANCH": "", "PROJECT_COMMIT": "", "PROJECT_SUBMODULES": "", "FETCH_SINGLE_BRANCH": true}, "SVN": {"PROJECT_URL": "", "PROJECT_REVISION": ""}, "LOCAL": {"PROJECT_PATH": ""}, "PROJECT_FILES": {"FILE_PROJECT_CONF": "", "FILE_JOBS_CONF": "", "JOB_SCRIPTS_TYPE": ""}, "RERUN": {"RERUN": false, "RERUN_JOBLIST": ""}, "JOBS": {"LOCAL_SETUP": {"FILE": "templates/local_setup.sh", "PLATFORM": "LOCAL", "RUNNING": "once", "DEPENDENCIES": {}, "ADDITIONAL_FILES": []}, "SYNCHRONIZE": {"FILE": "templates/synchronize.sh", "PLATFORM": "LOCAL", "DEPENDENCIES": {"LOCAL_SETUP": {}}, "RUNNING": "once", "ADDITIONAL_FILES": []}, "REMOTE_SETUP": {"FILE": "templates/remote_setup.sh", "DEPENDENCIES": {"SYNCHRONIZE": {}}, "WALLCLOCK": "00:05", "RUNNING": "once", "ADDITIONAL_FILES": []}, "INI": {"FILE": "templates/ini.sh", "DEPENDENCIES": {"REMOTE_SETUP": {}}, "RUNNING": "member", "WALLCLOCK": "00:05", "ADDITIONAL_FILES": []}, "SIM": {"FILE": "templates/sim.sh", "DEPENDENCIES": {"INI": {}, "SIM-1": {}}, "RUNNING": "chunk", "WALLCLOCK": "00:05", "ADDITIONAL_FILES": []}, "POST": {"FILE": "templates/post.sh", "DEPENDENCIES": {"SIM": {}}, "RUNNING": "chunk", "WALLCLOCK": "00:05", "ADDITIONAL_FILES": []}, "CLEAN": {"FILE": "templates/clean.sh", "DEPENDENCIES": {"POST": {}}, "RUNNING": "chunk", "WALLCLOCK": "00:05", "ADDITIONAL_FILES": []}}, "PLATFORMS": {"MARENOSTRUM4": {"TYPE": "slurm", "HOST": "mn1.bsc.es", "PROJECT": "bsc32", "USER": "bsc32xxx", "QUEUE": "debug", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": false, "MAX_WALLCLOCK": "48:00", "TEMP_DIR": ""}, "MARENOSTRUM_ARCHIVE": {"TYPE": "ps", "HOST": "dt02.bsc.es", "PROJECT": "bsc32", "USER": "bsc32xxx", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": false, "TEST_SUITE": false}, "TRANSFER_NODE": {"TYPE": "ps", "HOST": "dt01.bsc.es", "PROJECT": "bsc32", "USER": "bsc32xxx", "ADD_PROJECT_TO_HOST": false, "SCRATCH_DIR": "/gpfs/scratch"}, "TRANSFER_NODE_BSCEARTH000": {"TYPE": "ps", "HOST": "bscearth000", "USER": "dbeltran", "PROJECT": "Earth", "ADD_PROJECT_TO_HOST": false, "QUEUE": "serial", "SCRATCH_DIR": "/esarchive/scratch"}, "BSCEARTH000": {"TYPE": "ps", "HOST": "bscearth000", "USER": "dbeltran", "PROJECT": "Earth", "ADD_PROJECT_TO_HOST": false, "QUEUE": "serial", "SCRATCH_DIR": "/esarchive/scratch"}, "NORD3": {"TYPE": "SLURM", "HOST": "nord1.bsc.es", "PROJECT": "bsc32", "USER": "bsc32xxx", "QUEUE": "debug", "SCRATCH_DIR": "/gpfs/scratch", "MAX_WALLCLOCK": "48:00"}, "ECMWF-XC40": {"TYPE": "ecaccess", "VERSION": "pbs", "HOST": "cca", "USER": "c3d", "PROJECT": "spesiccf", "ADD_PROJECT_TO_HOST": false, "SCRATCH_DIR": "/scratch/ms", "QUEUE": "np", "SERIAL_QUEUE": "ns", "MAX_WALLCLOCK": "48:00"}}, "ROOTDIR": "/home/dbeltran/new_autosubmit/a01o", "PROJDIR": "/home/dbeltran/new_autosubmit/a01o/proj/project_files"}');
INSERT INTO experiment_run VALUES(4,'2023-10-02-12:55:51','2023-10-02-12:56:04',1696244151,1696244164,'month',4,0,10,0,0,0,0,0,'{"CONFIG": {"AUTOSUBMIT_VERSION": "4.0.95", "MAXWAITINGJOBS": 20, "TOTALJOBS": 20, "SAFETYSLEEPTIME": 10, "RETRIALS": 0}, "MAIL": {"NOTIFICATIONS": false, "TO": null}, "STORAGE": {"TYPE": "pkl", "COPY_REMOTE_LOGS": true}, "DEFAULT": {"EXPID": "a04c", "HPCARCH": "local", "CUSTOM_CONFIG": "/home/dbeltran/new_autosubmit/a01o/proj/git_project/as_conf"}, "EXPERIMENT": {"DATELIST": 20220401, "MEMBERS": "fc0", "CHUNKSIZEUNIT": "month", "CHUNKSIZE": 4, "NUMCHUNKS": 2, "CHUNKINI": "", "CALENDAR": "standard"}, "PROJECT": {"PROJECT_TYPE": "none", "PROJECT_DESTINATION": ""}, "GIT": {"PROJECT_ORIGIN": "", "PROJECT_BRANCH": "", "PROJECT_COMMIT": "", "PROJECT_SUBMODULES": "", "FETCH_SINGLE_BRANCH": true}, "SVN": {"PROJECT_URL": "", "PROJECT_REVISION": ""}, "LOCAL": {"PROJECT_PATH": ""}, "PROJECT_FILES": {"FILE_PROJECT_CONF": "", "FILE_JOBS_CONF": "", "JOB_SCRIPTS_TYPE": ""}, "RERUN": {"RERUN": false, "RERUN_JOBLIST": ""}, "JOBS": {"LOCAL_SETUP": {"FILE": "templates/local_setup.sh", "PLATFORM": "LOCAL", "RUNNING": "once", "DEPENDENCIES": {}, "ADDITIONAL_FILES": []}, "SYNCHRONIZE": {"FILE": "templates/synchronize.sh", "PLATFORM": "LOCAL", "DEPENDENCIES": {"LOCAL_SETUP": {}}, "RUNNING": "once", "ADDITIONAL_FILES": []}, "REMOTE_SETUP": {"FILE": "templates/remote_setup.sh", "DEPENDENCIES": {"SYNCHRONIZE": {}}, "WALLCLOCK": "00:05", "RUNNING": "once", "ADDITIONAL_FILES": []}, "INI": {"FILE": "templates/ini.sh", "DEPENDENCIES": {"REMOTE_SETUP": {}}, "RUNNING": "member", "WALLCLOCK": "00:05", "ADDITIONAL_FILES": []}, "SIM": {"FILE": "templates/sim.sh", "DEPENDENCIES": {"INI": {}, "SIM-1": {}}, "RUNNING": "chunk", "WALLCLOCK": "00:05", "ADDITIONAL_FILES": []}, "POST": {"FILE": "templates/post.sh", "DEPENDENCIES": {"SIM": {}}, "RUNNING": "chunk", "WALLCLOCK": "00:05", "ADDITIONAL_FILES": []}, "CLEAN": {"FILE": "templates/clean.sh", "DEPENDENCIES": {"POST": {}}, "RUNNING": "chunk", "WALLCLOCK": "00:05", "ADDITIONAL_FILES": []}}, "PLATFORMS": {"MARENOSTRUM4": {"TYPE": "slurm", "HOST": "mn1.bsc.es", "PROJECT": "bsc32", "USER": "bsc32xxx", "QUEUE": "debug", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": false, "MAX_WALLCLOCK": "48:00", "TEMP_DIR": ""}, "MARENOSTRUM_ARCHIVE": {"TYPE": "ps", "HOST": "dt02.bsc.es", "PROJECT": "bsc32", "USER": "bsc32xxx", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": false, "TEST_SUITE": false}, "TRANSFER_NODE": {"TYPE": "ps", "HOST": "dt01.bsc.es", "PROJECT": "bsc32", "USER": "bsc32xxx", "ADD_PROJECT_TO_HOST": false, "SCRATCH_DIR": "/gpfs/scratch"}, "TRANSFER_NODE_BSCEARTH000": {"TYPE": "ps", "HOST": "bscearth000", "USER": "dbeltran", "PROJECT": "Earth", "ADD_PROJECT_TO_HOST": false, "QUEUE": "serial", "SCRATCH_DIR": "/esarchive/scratch"}, "BSCEARTH000": {"TYPE": "ps", "HOST": "bscearth000", "USER": "dbeltran", "PROJECT": "Earth", "ADD_PROJECT_TO_HOST": false, "QUEUE": "serial", "SCRATCH_DIR": "/esarchive/scratch"}, "NORD3": {"TYPE": "SLURM", "HOST": "nord1.bsc.es", "PROJECT": "bsc32", "USER": "bsc32xxx", "QUEUE": "debug", "SCRATCH_DIR": "/gpfs/scratch", "MAX_WALLCLOCK": "48:00"}, "ECMWF-XC40": {"TYPE": "ecaccess", "VERSION": "pbs", "HOST": "cca", "USER": "c3d", "PROJECT": "spesiccf", "ADD_PROJECT_TO_HOST": false, "SCRATCH_DIR": "/scratch/ms", "QUEUE": "np", "SERIAL_QUEUE": "ns", "MAX_WALLCLOCK": "48:00"}}, "ROOTDIR": "/home/dbeltran/new_autosubmit/a01o", "PROJDIR": "/home/dbeltran/new_autosubmit/a01o/proj/project_files"}');
INSERT INTO experiment_run VALUES(5,'2023-10-02-12:56:04','2023-10-02-13:07:58',1696244164,1696244878,'month',4,10,10,0,0,0,0,0,'{"CONFIG": {"AUTOSUBMIT_VERSION": "4.0.95", "MAXWAITINGJOBS": 20, "TOTALJOBS": 20, "SAFETYSLEEPTIME": 10, "RETRIALS": 0}, "MAIL": {"NOTIFICATIONS": false, "TO": null}, "STORAGE": {"TYPE": "pkl", "COPY_REMOTE_LOGS": true}, "DEFAULT": {"EXPID": "a04c", "HPCARCH": "local", "CUSTOM_CONFIG": "/home/dbeltran/new_autosubmit/a01o/proj/git_project/as_conf"}, "EXPERIMENT": {"DATELIST": 20220401, "MEMBERS": "fc0", "CHUNKSIZEUNIT": "month", "CHUNKSIZE": 4, "NUMCHUNKS": 2, "CHUNKINI": "", "CALENDAR": "standard"}, "PROJECT": {"PROJECT_TYPE": "none", "PROJECT_DESTINATION": ""}, "GIT": {"PROJECT_ORIGIN": "", "PROJECT_BRANCH": "", "PROJECT_COMMIT": "", "PROJECT_SUBMODULES": "", "FETCH_SINGLE_BRANCH": true}, "SVN": {"PROJECT_URL": "", "PROJECT_REVISION": ""}, "LOCAL": {"PROJECT_PATH": ""}, "PROJECT_FILES": {"FILE_PROJECT_CONF": "", "FILE_JOBS_CONF": "", "JOB_SCRIPTS_TYPE": ""}, "RERUN": {"RERUN": false, "RERUN_JOBLIST": ""}, "JOBS": {"LOCAL_SETUP": {"FILE": "templates/local_setup.sh", "PLATFORM": "LOCAL", "RUNNING": "once", "DEPENDENCIES": {}, "ADDITIONAL_FILES": []}, "SYNCHRONIZE": {"FILE": "templates/synchronize.sh", "PLATFORM": "LOCAL", "DEPENDENCIES": {"LOCAL_SETUP": {}}, "RUNNING": "once", "ADDITIONAL_FILES": []}, "REMOTE_SETUP": {"FILE": "templates/remote_setup.sh", "DEPENDENCIES": {"SYNCHRONIZE": {}}, "WALLCLOCK": "00:05", "RUNNING": "once", "ADDITIONAL_FILES": []}, "INI": {"FILE": "templates/ini.sh", "DEPENDENCIES": {"REMOTE_SETUP": {}}, "RUNNING": "member", "WALLCLOCK": "00:05", "ADDITIONAL_FILES": []}, "SIM": {"FILE": "templates/sim.sh", "DEPENDENCIES": {"INI": {}, "SIM-1": {}}, "RUNNING": "chunk", "WALLCLOCK": "00:05", "ADDITIONAL_FILES": []}, "POST": {"FILE": "templates/post.sh", "DEPENDENCIES": {"SIM": {}}, "RUNNING": "chunk", "WALLCLOCK": "00:05", "ADDITIONAL_FILES": []}, "CLEAN": {"FILE": "templates/clean.sh", "DEPENDENCIES": {"POST": {}}, "RUNNING": "chunk", "WALLCLOCK": "00:05", "ADDITIONAL_FILES": []}}, "PLATFORMS": {"MARENOSTRUM4": {"TYPE": "slurm", "HOST": "mn1.bsc.es", "PROJECT": "bsc32", "USER": "bsc32xxx", "QUEUE": "debug", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": false, "MAX_WALLCLOCK": "48:00", "TEMP_DIR": ""}, "MARENOSTRUM_ARCHIVE": {"TYPE": "ps", "HOST": "dt02.bsc.es", "PROJECT": "bsc32", "USER": "bsc32xxx", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": false, "TEST_SUITE": false}, "TRANSFER_NODE": {"TYPE": "ps", "HOST": "dt01.bsc.es", "PROJECT": "bsc32", "USER": "bsc32xxx", "ADD_PROJECT_TO_HOST": false, "SCRATCH_DIR": "/gpfs/scratch"}, "TRANSFER_NODE_BSCEARTH000": {"TYPE": "ps", "HOST": "bscearth000", "USER": "dbeltran", "PROJECT": "Earth", "ADD_PROJECT_TO_HOST": false, "QUEUE": "serial", "SCRATCH_DIR": "/esarchive/scratch"}, "BSCEARTH000": {"TYPE": "ps", "HOST": "bscearth000", "USER": "dbeltran", "PROJECT": "Earth", "ADD_PROJECT_TO_HOST": false, "QUEUE": "serial", "SCRATCH_DIR": "/esarchive/scratch"}, "NORD3": {"TYPE": "SLURM", "HOST": "nord1.bsc.es", "PROJECT": "bsc32", "USER": "bsc32xxx", "QUEUE": "debug", "SCRATCH_DIR": "/gpfs/scratch", "MAX_WALLCLOCK": "48:00"}, "ECMWF-XC40": {"TYPE": "ecaccess", "VERSION": "pbs", "HOST": "cca", "USER": "c3d", "PROJECT": "spesiccf", "ADD_PROJECT_TO_HOST": false, "SCRATCH_DIR": "/scratch/ms", "QUEUE": "np", "SERIAL_QUEUE": "ns", "MAX_WALLCLOCK": "48:00"}}, "ROOTDIR": "/home/dbeltran/new_autosubmit/a01o", "PROJDIR": "/home/dbeltran/new_autosubmit/a01o/proj/project_files"}');
INSERT INTO experiment_run VALUES(6,'2023-10-02-13:07:58','2023-10-02-13:14:27',1696244878,1696245267,'month',4,10,10,0,0,0,0,0,'{"CONFIG": {"AUTOSUBMIT_VERSION": "4.0.95", "MAXWAITINGJOBS": 20, "TOTALJOBS": 20, "SAFETYSLEEPTIME": 10, "RETRIALS": 0}, "MAIL": {"NOTIFICATIONS": false, "TO": null}, "STORAGE": {"TYPE": "pkl", "COPY_REMOTE_LOGS": true}, "DEFAULT": {"EXPID": "a04c", "HPCARCH": "local", "CUSTOM_CONFIG": "/home/dbeltran/new_autosubmit/a01o/proj/git_project/as_conf"}, "EXPERIMENT": {"DATELIST": 20220401, "MEMBERS": "fc0", "CHUNKSIZEUNIT": "month", "CHUNKSIZE": 4, "NUMCHUNKS": 2, "CHUNKINI": "", "CALENDAR": "standard"}, "PROJECT": {"PROJECT_TYPE": "none", "PROJECT_DESTINATION": ""}, "GIT": {"PROJECT_ORIGIN": "", "PROJECT_BRANCH": "", "PROJECT_COMMIT": "", "PROJECT_SUBMODULES": "", "FETCH_SINGLE_BRANCH": true}, "SVN": {"PROJECT_URL": "", "PROJECT_REVISION": ""}, "LOCAL": {"PROJECT_PATH": ""}, "PROJECT_FILES": {"FILE_PROJECT_CONF": "", "FILE_JOBS_CONF": "", "JOB_SCRIPTS_TYPE": ""}, "RERUN": {"RERUN": false, "RERUN_JOBLIST": ""}, "JOBS": {"LOCAL_SETUP": {"FILE": "templates/local_setup.sh", "PLATFORM": "LOCAL", "RUNNING": "once", "DEPENDENCIES": {}, "ADDITIONAL_FILES": []}, "SYNCHRONIZE": {"FILE": "templates/synchronize.sh", "PLATFORM": "LOCAL", "DEPENDENCIES": {"LOCAL_SETUP": {}}, "RUNNING": "once", "ADDITIONAL_FILES": []}, "REMOTE_SETUP": {"FILE": "templates/remote_setup.sh", "DEPENDENCIES": {"SYNCHRONIZE": {}}, "WALLCLOCK": "00:05", "RUNNING": "once", "ADDITIONAL_FILES": []}, "INI": {"FILE": "templates/ini.sh", "DEPENDENCIES": {"REMOTE_SETUP": {}}, "RUNNING": "member", "WALLCLOCK": "00:05", "ADDITIONAL_FILES": []}, "SIM": {"FILE": "templates/sim.sh", "DEPENDENCIES": {"INI": {}, "SIM-1": {}}, "RUNNING": "chunk", "WALLCLOCK": "00:05", "ADDITIONAL_FILES": []}, "POST": {"FILE": "templates/post.sh", "DEPENDENCIES": {"SIM": {}}, "RUNNING": "chunk", "WALLCLOCK": "00:05", "ADDITIONAL_FILES": []}, "CLEAN": {"FILE": "templates/clean.sh", "DEPENDENCIES": {"POST": {}}, "RUNNING": "chunk", "WALLCLOCK": "00:05", "ADDITIONAL_FILES": []}}, "PLATFORMS": {"MARENOSTRUM4": {"TYPE": "slurm", "HOST": "mn1.bsc.es", "PROJECT": "bsc32", "USER": "bsc32xxx", "QUEUE": "debug", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": false, "MAX_WALLCLOCK": "48:00", "TEMP_DIR": ""}, "MARENOSTRUM_ARCHIVE": {"TYPE": "ps", "HOST": "dt02.bsc.es", "PROJECT": "bsc32", "USER": "bsc32xxx", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": false, "TEST_SUITE": false}, "TRANSFER_NODE": {"TYPE": "ps", "HOST": "dt01.bsc.es", "PROJECT": "bsc32", "USER": "bsc32xxx", "ADD_PROJECT_TO_HOST": false, "SCRATCH_DIR": "/gpfs/scratch"}, "TRANSFER_NODE_BSCEARTH000": {"TYPE": "ps", "HOST": "bscearth000", "USER": "dbeltran", "PROJECT": "Earth", "ADD_PROJECT_TO_HOST": false, "QUEUE": "serial", "SCRATCH_DIR": "/esarchive/scratch"}, "BSCEARTH000": {"TYPE": "ps", "HOST": "bscearth000", "USER": "dbeltran", "PROJECT": "Earth", "ADD_PROJECT_TO_HOST": false, "QUEUE": "serial", "SCRATCH_DIR": "/esarchive/scratch"}, "NORD3": {"TYPE": "SLURM", "HOST": "nord1.bsc.es", "PROJECT": "bsc32", "USER": "bsc32xxx", "QUEUE": "debug", "SCRATCH_DIR": "/gpfs/scratch", "MAX_WALLCLOCK": "48:00"}, "ECMWF-XC40": {"TYPE": "ecaccess", "VERSION": "pbs", "HOST": "cca", "USER": "c3d", "PROJECT": "spesiccf", "ADD_PROJECT_TO_HOST": false, "SCRATCH_DIR": "/scratch/ms", "QUEUE": "np", "SERIAL_QUEUE": "ns", "MAX_WALLCLOCK": "48:00"}}, "ROOTDIR": "/home/dbeltran/new_autosubmit/a01o", "PROJDIR": "/home/dbeltran/new_autosubmit/a01o/proj/project_files"}');
INSERT INTO experiment_run VALUES(7,'2023-10-02-13:14:27','2023-10-02-13:16:46',1696245267,1696245406,'month',4,5,10,0,0,0,2,0,'{"CONFIG": {"AUTOSUBMIT_VERSION": "4.0.95", "MAXWAITINGJOBS": 20, "TOTALJOBS": 20, "SAFETYSLEEPTIME": 10, "RETRIALS": 0}, "MAIL": {"NOTIFICATIONS": false, "TO": null}, "STORAGE": {"TYPE": "pkl", "COPY_REMOTE_LOGS": true}, "DEFAULT": {"EXPID": "a04c", "HPCARCH": "local", "CUSTOM_CONFIG": "/home/dbeltran/new_autosubmit/a01o/proj/git_project/as_conf"}, "EXPERIMENT": {"DATELIST": 20220401, "MEMBERS": "fc0", "CHUNKSIZEUNIT": "month", "CHUNKSIZE": 4, "NUMCHUNKS": 2, "CHUNKINI": "", "CALENDAR": "standard"}, "PROJECT": {"PROJECT_TYPE": "none", "PROJECT_DESTINATION": ""}, "GIT": {"PROJECT_ORIGIN": "", "PROJECT_BRANCH": "", "PROJECT_COMMIT": "", "PROJECT_SUBMODULES": "", "FETCH_SINGLE_BRANCH": true}, "SVN": {"PROJECT_URL": "", "PROJECT_REVISION": ""}, "LOCAL": {"PROJECT_PATH": ""}, "PROJECT_FILES": {"FILE_PROJECT_CONF": "", "FILE_JOBS_CONF": "", "JOB_SCRIPTS_TYPE": ""}, "RERUN": {"RERUN": false, "RERUN_JOBLIST": ""}, "JOBS": {"LOCAL_SETUP": {"FILE": "templates/local_setup.sh", "PLATFORM": "LOCAL", "RUNNING": "once", "DEPENDENCIES": {}, "ADDITIONAL_FILES": []}, "SYNCHRONIZE": {"FILE": "templates/synchronize.sh", "PLATFORM": "LOCAL", "DEPENDENCIES": {"LOCAL_SETUP": {}}, "RUNNING": "once", "ADDITIONAL_FILES": []}, "REMOTE_SETUP": {"FILE": "templates/remote_setup.sh", "DEPENDENCIES": {"SYNCHRONIZE": {}}, "WALLCLOCK": "00:05", "RUNNING": "once", "ADDITIONAL_FILES": []}, "INI": {"FILE": "templates/ini.sh", "DEPENDENCIES": {"REMOTE_SETUP": {}}, "RUNNING": "member", "WALLCLOCK": "00:05", "ADDITIONAL_FILES": []}, "SIM": {"FILE": "templates/sim.sh", "DEPENDENCIES": {"INI": {}, "SIM-1": {}}, "RUNNING": "chunk", "WALLCLOCK": "00:05", "ADDITIONAL_FILES": []}, "POST": {"FILE": "templates/post.sh", "DEPENDENCIES": {"SIM": {}}, "RUNNING": "chunk", "WALLCLOCK": "00:05", "ADDITIONAL_FILES": []}, "CLEAN": {"FILE": "templates/clean.sh", "DEPENDENCIES": {"POST": {}}, "RUNNING": "chunk", "WALLCLOCK": "00:05", "ADDITIONAL_FILES": []}}, "PLATFORMS": {"MARENOSTRUM4": {"TYPE": "slurm", "HOST": "mn1.bsc.es", "PROJECT": "bsc32", "USER": "bsc32xxx", "QUEUE": "debug", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": false, "MAX_WALLCLOCK": "48:00", "TEMP_DIR": ""}, "MARENOSTRUM_ARCHIVE": {"TYPE": "ps", "HOST": "dt02.bsc.es", "PROJECT": "bsc32", "USER": "bsc32xxx", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": false, "TEST_SUITE": false}, "TRANSFER_NODE": {"TYPE": "ps", "HOST": "dt01.bsc.es", "PROJECT": "bsc32", "USER": "bsc32xxx", "ADD_PROJECT_TO_HOST": false, "SCRATCH_DIR": "/gpfs/scratch"}, "TRANSFER_NODE_BSCEARTH000": {"TYPE": "ps", "HOST": "bscearth000", "USER": "dbeltran", "PROJECT": "Earth", "ADD_PROJECT_TO_HOST": false, "QUEUE": "serial", "SCRATCH_DIR": "/esarchive/scratch"}, "BSCEARTH000": {"TYPE": "ps", "HOST": "bscearth000", "USER": "dbeltran", "PROJECT": "Earth", "ADD_PROJECT_TO_HOST": false, "QUEUE": "serial", "SCRATCH_DIR": "/esarchive/scratch"}, "NORD3": {"TYPE": "SLURM", "HOST": "nord1.bsc.es", "PROJECT": "bsc32", "USER": "bsc32xxx", "QUEUE": "debug", "SCRATCH_DIR": "/gpfs/scratch", "MAX_WALLCLOCK": "48:00"}, "ECMWF-XC40": {"TYPE": "ecaccess", "VERSION": "pbs", "HOST": "cca", "USER": "c3d", "PROJECT": "spesiccf", "ADD_PROJECT_TO_HOST": false, "SCRATCH_DIR": "/scratch/ms", "QUEUE": "np", "SERIAL_QUEUE": "ns", "MAX_WALLCLOCK": "48:00"}}, "ROOTDIR": "/home/dbeltran/new_autosubmit/a01o", "PROJDIR": "/home/dbeltran/new_autosubmit/a01o/proj/project_files"}');
INSERT INTO experiment_run VALUES(8,'2023-10-02-13:16:46','2023-10-02-13:16:52',1696245406,1696245412,'month',4,0,10,0,0,0,0,0,'{"CONFIG": {"AUTOSUBMIT_VERSION": "4.0.95", "MAXWAITINGJOBS": 20, "TOTALJOBS": 20, "SAFETYSLEEPTIME": 10, "RETRIALS": 0}, "MAIL": {"NOTIFICATIONS": false, "TO": null}, "STORAGE": {"TYPE": "pkl", "COPY_REMOTE_LOGS": true}, "EXPERIMENT": {"DATELIST": 20220401, "MEMBERS": "fc0", "CHUNKSIZEUNIT": "month", "CHUNKSIZE": 4, "NUMCHUNKS": 2, "CHUNKINI": "", "CALENDAR": "standard"}, "PROJECT_FILES": {"FILE_PROJECT_CONF": "", "FILE_JOBS_CONF": "", "JOB_SCRIPTS_TYPE": ""}, "RERUN": {"RERUN": false, "RERUN_JOBLIST": ""}, "JOBS": {"LOCAL_SETUP": {"FILE": "templates/local_setup.sh", "PLATFORM": "LOCAL", "RUNNING": "once", "DEPENDENCIES": {}, "ADDITIONAL_FILES": []}, "SYNCHRONIZE": {"FILE": "templates/synchronize.sh", "PLATFORM": "LOCAL", "DEPENDENCIES": {"LOCAL_SETUP": {}}, "RUNNING": "once", "ADDITIONAL_FILES": []}, "REMOTE_SETUP": {"FILE": "templates/remote_setup.sh", "DEPENDENCIES": {"SYNCHRONIZE": {}}, "WALLCLOCK": "00:05", "RUNNING": "once", "ADDITIONAL_FILES": []}, "INI": {"FILE": "templates/ini.sh", "DEPENDENCIES": {"REMOTE_SETUP": {}}, "RUNNING": "member", "WALLCLOCK": "00:05", "ADDITIONAL_FILES": []}, "SIM": {"FILE": "templates/sim.sh", "DEPENDENCIES": {"INI": {}, "SIM-1": {}}, "RUNNING": "chunk", "WALLCLOCK": "00:05", "ADDITIONAL_FILES": []}, "POST": {"FILE": "templates/post.sh", "DEPENDENCIES": {"SIM": {}}, "RUNNING": "chunk", "WALLCLOCK": "00:05", "ADDITIONAL_FILES": []}, "CLEAN": {"FILE": "templates/clean.sh", "DEPENDENCIES": {"POST": {}}, "RUNNING": "chunk", "WALLCLOCK": "00:05", "ADDITIONAL_FILES": []}}, "PLATFORMS": {"MARENOSTRUM4": {"TYPE": "slurm", "HOST": "mn1.bsc.es", "PROJECT": "bsc32", "USER": "bsc32xxx", "QUEUE": "debug", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": false, "MAX_WALLCLOCK": "48:00", "TEMP_DIR": ""}, "MARENOSTRUM_ARCHIVE": {"TYPE": "ps", "HOST": "dt02.bsc.es", "PROJECT": "bsc32", "USER": "bsc32xxx", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": false, "TEST_SUITE": false}, "TRANSFER_NODE": {"TYPE": "ps", "HOST": "dt01.bsc.es", "PROJECT": "bsc32", "USER": "bsc32xxx", "ADD_PROJECT_TO_HOST": false, "SCRATCH_DIR": "/gpfs/scratch"}, "TRANSFER_NODE_BSCEARTH000": {"TYPE": "ps", "HOST": "bscearth000", "USER": "dbeltran", "PROJECT": "Earth", "ADD_PROJECT_TO_HOST": false, "QUEUE": "serial", "SCRATCH_DIR": "/esarchive/scratch"}, "BSCEARTH000": {"TYPE": "ps", "HOST": "bscearth000", "USER": "dbeltran", "PROJECT": "Earth", "ADD_PROJECT_TO_HOST": false, "QUEUE": "serial", "SCRATCH_DIR": "/esarchive/scratch"}, "NORD3": {"TYPE": "SLURM", "HOST": "nord1.bsc.es", "PROJECT": "bsc32", "USER": "bsc32xxx", "QUEUE": "debug", "SCRATCH_DIR": "/gpfs/scratch", "MAX_WALLCLOCK": "48:00"}, "ECMWF-XC40": {"TYPE": "ecaccess", "VERSION": "pbs", "HOST": "cca", "USER": "c3d", "PROJECT": "spesiccf", "ADD_PROJECT_TO_HOST": false, "SCRATCH_DIR": "/scratch/ms", "QUEUE": "np", "SERIAL_QUEUE": "ns", "MAX_WALLCLOCK": "48:00"}}, "ROOTDIR": "/home/dbeltran/new_autosubmit/a01o", "PROJDIR": "/home/dbeltran/new_autosubmit/a01o/proj/project_files", "DEFAULT": {"EXPID": "a01o", "HPCARCH": "marenostrum4", "CUSTOM_CONFIG": "/home/dbeltran/new_autosubmit/a01o/proj/git_project/as_conf"}, "PROJECT": {"PROJECT_TYPE": "git", "PROJECT_DESTINATION": "git_project"}, "GIT": {"PROJECT_ORIGIN": "https://earth.bsc.es/gitlab/dbeltran/edito-vanilla", "PROJECT_BRANCH": "main", "PROJECT_COMMIT": "", "PROJECT_SUBMODULES": "", "FETCH_SINGLE_BRANCH": true}}');
INSERT INTO experiment_run VALUES(9,'2023-10-02-13:16:52','2023-10-02-13:22:03',1696245412,1696245723,'month',4,0,10,0,0,0,0,0,'{"CONFIG": {"AUTOSUBMIT_VERSION": "4.0.95", "MAXWAITINGJOBS": 20, "TOTALJOBS": 20, "SAFETYSLEEPTIME": 10, "RETRIALS": 0}, "MAIL": {"NOTIFICATIONS": false, "TO": null}, "STORAGE": {"TYPE": "pkl", "COPY_REMOTE_LOGS": true}, "EXPERIMENT": {"DATELIST": 20220401, "MEMBERS": "fc0", "CHUNKSIZEUNIT": "month", "CHUNKSIZE": 4, "NUMCHUNKS": 2, "CHUNKINI": "", "CALENDAR": "standard"}, "PROJECT_FILES": {"FILE_PROJECT_CONF": "", "FILE_JOBS_CONF": "", "JOB_SCRIPTS_TYPE": ""}, "RERUN": {"RERUN": false, "RERUN_JOBLIST": ""}, "JOBS": {"LOCAL_SETUP": {"FILE": "templates/local_setup.sh", "PLATFORM": "LOCAL", "RUNNING": "once", "DEPENDENCIES": {}, "ADDITIONAL_FILES": []}, "SYNCHRONIZE": {"FILE": "templates/synchronize.sh", "PLATFORM": "LOCAL", "DEPENDENCIES": {"LOCAL_SETUP": {}}, "RUNNING": "once", "ADDITIONAL_FILES": []}, "REMOTE_SETUP": {"FILE": "templates/remote_setup.sh", "DEPENDENCIES": {"SYNCHRONIZE": {}}, "WALLCLOCK": "00:05", "RUNNING": "once", "ADDITIONAL_FILES": []}, "INI": {"FILE": "templates/ini.sh", "DEPENDENCIES": {"REMOTE_SETUP": {}}, "RUNNING": "member", "WALLCLOCK": "00:05", "ADDITIONAL_FILES": []}, "SIM": {"FILE": "templates/sim.sh", "DEPENDENCIES": {"INI": {}, "SIM-1": {}}, "RUNNING": "chunk", "WALLCLOCK": "00:05", "ADDITIONAL_FILES": []}, "POST": {"FILE": "templates/post.sh", "DEPENDENCIES": {"SIM": {}}, "RUNNING": "chunk", "WALLCLOCK": "00:05", "ADDITIONAL_FILES": []}, "CLEAN": {"FILE": "templates/clean.sh", "DEPENDENCIES": {"POST": {}}, "RUNNING": "chunk", "WALLCLOCK": "00:05", "ADDITIONAL_FILES": []}}, "PLATFORMS": {"MARENOSTRUM4": {"TYPE": "slurm", "HOST": "mn1.bsc.es", "PROJECT": "bsc32", "USER": "bsc32xxx", "QUEUE": "debug", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": false, "MAX_WALLCLOCK": "48:00", "TEMP_DIR": ""}, "MARENOSTRUM_ARCHIVE": {"TYPE": "ps", "HOST": "dt02.bsc.es", "PROJECT": "bsc32", "USER": "bsc32xxx", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": false, "TEST_SUITE": false}, "TRANSFER_NODE": {"TYPE": "ps", "HOST": "dt01.bsc.es", "PROJECT": "bsc32", "USER": "bsc32xxx", "ADD_PROJECT_TO_HOST": false, "SCRATCH_DIR": "/gpfs/scratch"}, "TRANSFER_NODE_BSCEARTH000": {"TYPE": "ps", "HOST": "bscearth000", "USER": "dbeltran", "PROJECT": "Earth", "ADD_PROJECT_TO_HOST": false, "QUEUE": "serial", "SCRATCH_DIR": "/esarchive/scratch"}, "BSCEARTH000": {"TYPE": "ps", "HOST": "bscearth000", "USER": "dbeltran", "PROJECT": "Earth", "ADD_PROJECT_TO_HOST": false, "QUEUE": "serial", "SCRATCH_DIR": "/esarchive/scratch"}, "NORD3": {"TYPE": "SLURM", "HOST": "nord1.bsc.es", "PROJECT": "bsc32", "USER": "bsc32xxx", "QUEUE": "debug", "SCRATCH_DIR": "/gpfs/scratch", "MAX_WALLCLOCK": "48:00"}, "ECMWF-XC40": {"TYPE": "ecaccess", "VERSION": "pbs", "HOST": "cca", "USER": "c3d", "PROJECT": "spesiccf", "ADD_PROJECT_TO_HOST": false, "SCRATCH_DIR": "/scratch/ms", "QUEUE": "np", "SERIAL_QUEUE": "ns", "MAX_WALLCLOCK": "48:00"}}, "ROOTDIR": "/home/dbeltran/new_autosubmit/a01o", "PROJDIR": "/home/dbeltran/new_autosubmit/a01o/proj/project_files", "DEFAULT": {"EXPID": "a01o", "HPCARCH": "marenostrum4", "CUSTOM_CONFIG": "/home/dbeltran/new_autosubmit/a01o/proj/git_project/as_conf"}, "PROJECT": {"PROJECT_TYPE": "git", "PROJECT_DESTINATION": "git_project"}, "GIT": {"PROJECT_ORIGIN": "https://earth.bsc.es/gitlab/dbeltran/edito-vanilla", "PROJECT_BRANCH": "main", "PROJECT_COMMIT": "", "PROJECT_SUBMODULES": "", "FETCH_SINGLE_BRANCH": true}}');
INSERT INTO experiment_run VALUES(10,'2023-10-02-13:22:03','2023-10-02-13:22:12',1696245723,1696245732,'month',4,0,10,0,0,0,0,0,'{"CONFIG": {"AUTOSUBMIT_VERSION": "4.0.95", "MAXWAITINGJOBS": 20, "TOTALJOBS": 20, "SAFETYSLEEPTIME": 10, "RETRIALS": 0}, "MAIL": {"NOTIFICATIONS": false, "TO": null}, "STORAGE": {"TYPE": "pkl", "COPY_REMOTE_LOGS": true}, "EXPERIMENT": {"DATELIST": 20220401, "MEMBERS": "fc0", "CHUNKSIZEUNIT": "month", "CHUNKSIZE": 4, "NUMCHUNKS": 2, "CHUNKINI": "", "CALENDAR": "standard"}, "PROJECT_FILES": {"FILE_PROJECT_CONF": "", "FILE_JOBS_CONF": "", "JOB_SCRIPTS_TYPE": ""}, "RERUN": {"RERUN": false, "RERUN_JOBLIST": ""}, "JOBS": {"LOCAL_SETUP": {"FILE": "templates/local_setup.sh", "PLATFORM": "LOCAL", "RUNNING": "once", "DEPENDENCIES": {}, "ADDITIONAL_FILES": []}, "SYNCHRONIZE": {"FILE": "templates/synchronize.sh", "PLATFORM": "LOCAL", "DEPENDENCIES": {"LOCAL_SETUP": {}}, "RUNNING": "once", "ADDITIONAL_FILES": []}, "REMOTE_SETUP": {"FILE": "templates/remote_setup.sh", "DEPENDENCIES": {"SYNCHRONIZE": {}}, "WALLCLOCK": "00:05", "RUNNING": "once", "ADDITIONAL_FILES": []}, "INI": {"FILE": "templates/ini.sh", "DEPENDENCIES": {"REMOTE_SETUP": {}}, "RUNNING": "member", "WALLCLOCK": "00:05", "ADDITIONAL_FILES": []}, "SIM": {"FILE": "templates/sim.sh", "DEPENDENCIES": {"INI": {}, "SIM-1": {}}, "RUNNING": "chunk", "WALLCLOCK": "00:05", "ADDITIONAL_FILES": []}, "POST": {"FILE": "templates/post.sh", "DEPENDENCIES": {"SIM": {}}, "RUNNING": "chunk", "WALLCLOCK": "00:05", "ADDITIONAL_FILES": []}, "CLEAN": {"FILE": "templates/clean.sh", "DEPENDENCIES": {"POST": {}}, "RUNNING": "chunk", "WALLCLOCK": "00:05", "ADDITIONAL_FILES": []}}, "PLATFORMS": {"MARENOSTRUM4": {"TYPE": "slurm", "HOST": "mn1.bsc.es", "PROJECT": "bsc32", "USER": "bsc32079", "QUEUE": "debug", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": false, "MAX_WALLCLOCK": "48:00", "TEMP_DIR": ""}, "MARENOSTRUM_ARCHIVE": {"TYPE": "ps", "HOST": "dt02.bsc.es", "PROJECT": "bsc32", "USER": "bsc32xxx", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": false, "TEST_SUITE": false}, "TRANSFER_NODE": {"TYPE": "ps", "HOST": "dt01.bsc.es", "PROJECT": "bsc32", "USER": "bsc32xxx", "ADD_PROJECT_TO_HOST": false, "SCRATCH_DIR": "/gpfs/scratch"}, "TRANSFER_NODE_BSCEARTH000": {"TYPE": "ps", "HOST": "bscearth000", "USER": "dbeltran", "PROJECT": "Earth", "ADD_PROJECT_TO_HOST": false, "QUEUE": "serial", "SCRATCH_DIR": "/esarchive/scratch"}, "BSCEARTH000": {"TYPE": "ps", "HOST": "bscearth000", "USER": "dbeltran", "PROJECT": "Earth", "ADD_PROJECT_TO_HOST": false, "QUEUE": "serial", "SCRATCH_DIR": "/esarchive/scratch"}, "NORD3": {"TYPE": "SLURM", "HOST": "nord1.bsc.es", "PROJECT": "bsc32", "USER": "bsc32xxx", "QUEUE": "debug", "SCRATCH_DIR": "/gpfs/scratch", "MAX_WALLCLOCK": "48:00"}, "ECMWF-XC40": {"TYPE": "ecaccess", "VERSION": "pbs", "HOST": "cca", "USER": "c3d", "PROJECT": "spesiccf", "ADD_PROJECT_TO_HOST": false, "SCRATCH_DIR": "/scratch/ms", "QUEUE": "np", "SERIAL_QUEUE": "ns", "MAX_WALLCLOCK": "48:00"}}, "ROOTDIR": "/home/dbeltran/new_autosubmit/a01o", "PROJDIR": "/home/dbeltran/new_autosubmit/a01o/proj/project_files", "DEFAULT": {"EXPID": "a01o", "HPCARCH": "marenostrum4", "CUSTOM_CONFIG": "/home/dbeltran/new_autosubmit/a01o/proj/git_project/as_conf"}, "PROJECT": {"PROJECT_TYPE": "git", "PROJECT_DESTINATION": "git_project"}, "GIT": {"PROJECT_ORIGIN": "https://earth.bsc.es/gitlab/dbeltran/edito-vanilla", "PROJECT_BRANCH": "main", "PROJECT_COMMIT": "", "PROJECT_SUBMODULES": "", "FETCH_SINGLE_BRANCH": true}}');
INSERT INTO experiment_run VALUES(11,'2023-10-02-13:22:12','2023-10-02-13:22:13',1696245732,1696245733,'month',4,0,10,0,0,0,0,0,'{"CONFIG": {"AUTOSUBMIT_VERSION": "4.0.95", "MAXWAITINGJOBS": 20, "TOTALJOBS": 20, "SAFETYSLEEPTIME": 10, "RETRIALS": 0}, "MAIL": {"NOTIFICATIONS": false, "TO": null}, "STORAGE": {"TYPE": "pkl", "COPY_REMOTE_LOGS": true}, "EXPERIMENT": {"DATELIST": 20220401, "MEMBERS": "fc0", "CHUNKSIZEUNIT": "month", "CHUNKSIZE": 4, "NUMCHUNKS": 2, "CHUNKINI": "", "CALENDAR": "standard"}, "PROJECT_FILES": {"FILE_PROJECT_CONF": "", "FILE_JOBS_CONF": "", "JOB_SCRIPTS_TYPE": ""}, "RERUN": {"RERUN": false, "RERUN_JOBLIST": ""}, "JOBS": {"LOCAL_SETUP": {"FILE": "templates/local_setup.sh", "PLATFORM": "LOCAL", "RUNNING": "once", "DEPENDENCIES": {}, "ADDITIONAL_FILES": []}, "SYNCHRONIZE": {"FILE": "templates/synchronize.sh", "PLATFORM": "LOCAL", "DEPENDENCIES": {"LOCAL_SETUP": {}}, "RUNNING": "once", "ADDITIONAL_FILES": []}, "REMOTE_SETUP": {"FILE": "templates/remote_setup.sh", "DEPENDENCIES": {"SYNCHRONIZE": {}}, "WALLCLOCK": "00:05", "RUNNING": "once", "ADDITIONAL_FILES": []}, "INI": {"FILE": "templates/ini.sh", "DEPENDENCIES": {"REMOTE_SETUP": {}}, "RUNNING": "member", "WALLCLOCK": "00:05", "ADDITIONAL_FILES": []}, "SIM": {"FILE": "templates/sim.sh", "DEPENDENCIES": {"INI": {}, "SIM-1": {}}, "RUNNING": "chunk", "WALLCLOCK": "00:05", "ADDITIONAL_FILES": []}, "POST": {"FILE": "templates/post.sh", "DEPENDENCIES": {"SIM": {}}, "RUNNING": "chunk", "WALLCLOCK": "00:05", "ADDITIONAL_FILES": []}, "CLEAN": {"FILE": "templates/clean.sh", "DEPENDENCIES": {"POST": {}}, "RUNNING": "chunk", "WALLCLOCK": "00:05", "ADDITIONAL_FILES": []}}, "PLATFORMS": {"MARENOSTRUM4": {"TYPE": "slurm", "HOST": "mn1.bsc.es", "PROJECT": "bsc32", "USER": "bsc32070", "QUEUE": "debug", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": false, "MAX_WALLCLOCK": "48:00", "TEMP_DIR": ""}, "MARENOSTRUM_ARCHIVE": {"TYPE": "ps", "HOST": "dt02.bsc.es", "PROJECT": "bsc32", "USER": "bsc32xxx", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": false, "TEST_SUITE": false}, "TRANSFER_NODE": {"TYPE": "ps", "HOST": "dt01.bsc.es", "PROJECT": "bsc32", "USER": "bsc32xxx", "ADD_PROJECT_TO_HOST": false, "SCRATCH_DIR": "/gpfs/scratch"}, "TRANSFER_NODE_BSCEARTH000": {"TYPE": "ps", "HOST": "bscearth000", "USER": "dbeltran", "PROJECT": "Earth", "ADD_PROJECT_TO_HOST": false, "QUEUE": "serial", "SCRATCH_DIR": "/esarchive/scratch"}, "BSCEARTH000": {"TYPE": "ps", "HOST": "bscearth000", "USER": "dbeltran", "PROJECT": "Earth", "ADD_PROJECT_TO_HOST": false, "QUEUE": "serial", "SCRATCH_DIR": "/esarchive/scratch"}, "NORD3": {"TYPE": "SLURM", "HOST": "nord1.bsc.es", "PROJECT": "bsc32", "USER": "bsc32xxx", "QUEUE": "debug", "SCRATCH_DIR": "/gpfs/scratch", "MAX_WALLCLOCK": "48:00"}, "ECMWF-XC40": {"TYPE": "ecaccess", "VERSION": "pbs", "HOST": "cca", "USER": "c3d", "PROJECT": "spesiccf", "ADD_PROJECT_TO_HOST": false, "SCRATCH_DIR": "/scratch/ms", "QUEUE": "np", "SERIAL_QUEUE": "ns", "MAX_WALLCLOCK": "48:00"}}, "ROOTDIR": "/home/dbeltran/new_autosubmit/a01o", "PROJDIR": "/home/dbeltran/new_autosubmit/a01o/proj/project_files", "DEFAULT": {"EXPID": "a01o", "HPCARCH": "marenostrum4", "CUSTOM_CONFIG": "/home/dbeltran/new_autosubmit/a01o/proj/git_project/as_conf"}, "PROJECT": {"PROJECT_TYPE": "git", "PROJECT_DESTINATION": "git_project"}, "GIT": {"PROJECT_ORIGIN": "https://earth.bsc.es/gitlab/dbeltran/edito-vanilla", "PROJECT_BRANCH": "main", "PROJECT_COMMIT": "", "PROJECT_SUBMODULES": "", "FETCH_SINGLE_BRANCH": true}}');
INSERT INTO experiment_run VALUES(12,'2023-10-02-13:22:13','2023-10-02-13:28:47',1696245733,1696246127,'month',4,1,10,0,0,0,1,0,'{"CONFIG": {"AUTOSUBMIT_VERSION": "4.0.95", "MAXWAITINGJOBS": 20, "TOTALJOBS": 20, "SAFETYSLEEPTIME": 10, "RETRIALS": 0}, "MAIL": {"NOTIFICATIONS": false, "TO": null}, "STORAGE": {"TYPE": "pkl", "COPY_REMOTE_LOGS": true}, "EXPERIMENT": {"DATELIST": 20220401, "MEMBERS": "fc0", "CHUNKSIZEUNIT": "month", "CHUNKSIZE": 4, "NUMCHUNKS": 2, "CHUNKINI": "", "CALENDAR": "standard"}, "PROJECT_FILES": {"FILE_PROJECT_CONF": "", "FILE_JOBS_CONF": "", "JOB_SCRIPTS_TYPE": ""}, "RERUN": {"RERUN": false, "RERUN_JOBLIST": ""}, "JOBS": {"LOCAL_SETUP": {"FILE": "templates/local_setup.sh", "PLATFORM": "LOCAL", "RUNNING": "once", "DEPENDENCIES": {}, "ADDITIONAL_FILES": []}, "SYNCHRONIZE": {"FILE": "templates/synchronize.sh", "PLATFORM": "LOCAL", "DEPENDENCIES": {"LOCAL_SETUP": {}}, "RUNNING": "once", "ADDITIONAL_FILES": []}, "REMOTE_SETUP": {"FILE": "templates/remote_setup.sh", "DEPENDENCIES": {"SYNCHRONIZE": {}}, "WALLCLOCK": "00:05", "RUNNING": "once", "ADDITIONAL_FILES": []}, "INI": {"FILE": "templates/ini.sh", "DEPENDENCIES": {"REMOTE_SETUP": {}}, "RUNNING": "member", "WALLCLOCK": "00:05", "ADDITIONAL_FILES": []}, "SIM": {"FILE": "templates/sim.sh", "DEPENDENCIES": {"INI": {}, "SIM-1": {}}, "RUNNING": "chunk", "WALLCLOCK": "00:05", "ADDITIONAL_FILES": []}, "POST": {"FILE": "templates/post.sh", "DEPENDENCIES": {"SIM": {}}, "RUNNING": "chunk", "WALLCLOCK": "00:05", "ADDITIONAL_FILES": []}, "CLEAN": {"FILE": "templates/clean.sh", "DEPENDENCIES": {"POST": {}}, "RUNNING": "chunk", "WALLCLOCK": "00:05", "ADDITIONAL_FILES": []}}, "PLATFORMS": {"MARENOSTRUM4": {"TYPE": "slurm", "HOST": "mn1.bsc.es", "PROJECT": "bsc32", "USER": "bsc32070", "QUEUE": "debug", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": false, "MAX_WALLCLOCK": "48:00", "TEMP_DIR": ""}, "MARENOSTRUM_ARCHIVE": {"TYPE": "ps", "HOST": "dt02.bsc.es", "PROJECT": "bsc32", "USER": "bsc32xxx", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": false, "TEST_SUITE": false}, "TRANSFER_NODE": {"TYPE": "ps", "HOST": "dt01.bsc.es", "PROJECT": "bsc32", "USER": "bsc32xxx", "ADD_PROJECT_TO_HOST": false, "SCRATCH_DIR": "/gpfs/scratch"}, "TRANSFER_NODE_BSCEARTH000": {"TYPE": "ps", "HOST": "bscearth000", "USER": "dbeltran", "PROJECT": "Earth", "ADD_PROJECT_TO_HOST": false, "QUEUE": "serial", "SCRATCH_DIR": "/esarchive/scratch"}, "BSCEARTH000": {"TYPE": "ps", "HOST": "bscearth000", "USER": "dbeltran", "PROJECT": "Earth", "ADD_PROJECT_TO_HOST": false, "QUEUE": "serial", "SCRATCH_DIR": "/esarchive/scratch"}, "NORD3": {"TYPE": "SLURM", "HOST": "nord1.bsc.es", "PROJECT": "bsc32", "USER": "bsc32xxx", "QUEUE": "debug", "SCRATCH_DIR": "/gpfs/scratch", "MAX_WALLCLOCK": "48:00"}, "ECMWF-XC40": {"TYPE": "ecaccess", "VERSION": "pbs", "HOST": "cca", "USER": "c3d", "PROJECT": "spesiccf", "ADD_PROJECT_TO_HOST": false, "SCRATCH_DIR": "/scratch/ms", "QUEUE": "np", "SERIAL_QUEUE": "ns", "MAX_WALLCLOCK": "48:00"}}, "ROOTDIR": "/home/dbeltran/new_autosubmit/a01o", "PROJDIR": "/home/dbeltran/new_autosubmit/a01o/proj/project_files", "DEFAULT": {"EXPID": "a01o", "HPCARCH": "marenostrum4", "CUSTOM_CONFIG": "/home/dbeltran/new_autosubmit/a01o/proj/git_project/as_conf"}, "PROJECT": {"PROJECT_TYPE": "git", "PROJECT_DESTINATION": "git_project"}, "GIT": {"PROJECT_ORIGIN": "https://earth.bsc.es/gitlab/dbeltran/edito-vanilla", "PROJECT_BRANCH": "main", "PROJECT_COMMIT": "", "PROJECT_SUBMODULES": "", "FETCH_SINGLE_BRANCH": true}}');
INSERT INTO experiment_run VALUES(13,'2023-10-02-13:28:47','2023-10-02-13:28:52',1696246127,1696246132,'month',4,0,10,0,0,0,0,0,'{"CONFIG": {"AUTOSUBMIT_VERSION": "4.0.95", "MAXWAITINGJOBS": 20, "TOTALJOBS": 20, "SAFETYSLEEPTIME": 10, "RETRIALS": 0}, "MAIL": {"NOTIFICATIONS": false, "TO": null}, "STORAGE": {"TYPE": "pkl", "COPY_REMOTE_LOGS": true}, "EXPERIMENT": {"DATELIST": 20220401, "MEMBERS": "fc0", "CHUNKSIZEUNIT": "month", "CHUNKSIZE": 4, "NUMCHUNKS": 2, "CHUNKINI": "", "CALENDAR": "standard"}, "PROJECT_FILES": {"FILE_PROJECT_CONF": "", "FILE_JOBS_CONF": "", "JOB_SCRIPTS_TYPE": ""}, "RERUN": {"RERUN": false, "RERUN_JOBLIST": ""}, "JOBS": {"LOCAL_SETUP": {"FILE": "templates/local_setup.sh", "PLATFORM": "LOCAL", "RUNNING": "once", "DEPENDENCIES": {}, "ADDITIONAL_FILES": []}, "SYNCHRONIZE": {"FILE": "templates/synchronize.sh", "PLATFORM": "LOCAL", "DEPENDENCIES": {"LOCAL_SETUP": {}}, "RUNNING": "once", "ADDITIONAL_FILES": []}, "REMOTE_SETUP": {"FILE": "templates/remote_setup.sh", "DEPENDENCIES": {"SYNCHRONIZE": {}}, "WALLCLOCK": "00:05", "RUNNING": "once", "ADDITIONAL_FILES": []}, "INI": {"FILE": "templates/ini.sh", "DEPENDENCIES": {"REMOTE_SETUP": {}}, "RUNNING": "member", "WALLCLOCK": "00:05", "ADDITIONAL_FILES": []}, "SIM": {"FILE": "templates/sim.sh", "DEPENDENCIES": {"INI": {}, "SIM-1": {}}, "RUNNING": "chunk", "WALLCLOCK": "00:05", "ADDITIONAL_FILES": []}, "POST": {"FILE": "templates/post.sh", "DEPENDENCIES": {"SIM": {}}, "RUNNING": "chunk", "WALLCLOCK": "00:05", "ADDITIONAL_FILES": []}, "CLEAN": {"FILE": "templates/clean.sh", "DEPENDENCIES": {"POST": {}}, "RUNNING": "chunk", "WALLCLOCK": "00:05", "ADDITIONAL_FILES": []}}, "PLATFORMS": {"MARENOSTRUM4": {"TYPE": "slurm", "HOST": "mn1.bsc.es", "PROJECT": "bsc32", "USER": "bsc32070", "QUEUE": "debug", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": false, "MAX_WALLCLOCK": "48:00", "TEMP_DIR": ""}, "MARENOSTRUM_ARCHIVE": {"TYPE": "ps", "HOST": "dt02.bsc.es", "PROJECT": "bsc32", "USER": "bsc32xxx", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": false, "TEST_SUITE": false}, "TRANSFER_NODE": {"TYPE": "ps", "HOST": "dt01.bsc.es", "PROJECT": "bsc32", "USER": "bsc32xxx", "ADD_PROJECT_TO_HOST": false, "SCRATCH_DIR": "/gpfs/scratch"}, "TRANSFER_NODE_BSCEARTH000": {"TYPE": "ps", "HOST": "bscearth000", "USER": "dbeltran", "PROJECT": "Earth", "ADD_PROJECT_TO_HOST": false, "QUEUE": "serial", "SCRATCH_DIR": "/esarchive/scratch"}, "BSCEARTH000": {"TYPE": "ps", "HOST": "bscearth000", "USER": "dbeltran", "PROJECT": "Earth", "ADD_PROJECT_TO_HOST": false, "QUEUE": "serial", "SCRATCH_DIR": "/esarchive/scratch"}, "NORD3": {"TYPE": "SLURM", "HOST": "nord1.bsc.es", "PROJECT": "bsc32", "USER": "bsc32xxx", "QUEUE": "debug", "SCRATCH_DIR": "/gpfs/scratch", "MAX_WALLCLOCK": "48:00"}, "ECMWF-XC40": {"TYPE": "ecaccess", "VERSION": "pbs", "HOST": "cca", "USER": "c3d", "PROJECT": "spesiccf", "ADD_PROJECT_TO_HOST": false, "SCRATCH_DIR": "/scratch/ms", "QUEUE": "np", "SERIAL_QUEUE": "ns", "MAX_WALLCLOCK": "48:00"}}, "ROOTDIR": "/home/dbeltran/new_autosubmit/a01o", "PROJDIR": "/home/dbeltran/new_autosubmit/a01o/proj/project_files", "DEFAULT": {"EXPID": "a01o", "HPCARCH": "marenostrum4", "CUSTOM_CONFIG": "/home/dbeltran/new_autosubmit/a01o/proj/git_project/as_conf"}, "PROJECT": {"PROJECT_TYPE": "git", "PROJECT_DESTINATION": "git_project"}, "GIT": {"PROJECT_ORIGIN": "https://earth.bsc.es/gitlab/dbeltran/edito-vanilla", "PROJECT_BRANCH": "main", "PROJECT_COMMIT": "", "PROJECT_SUBMODULES": "", "FETCH_SINGLE_BRANCH": true}}');
INSERT INTO experiment_run VALUES(14,'2023-10-02-13:28:52','2023-10-02-13:45:01',1696246132,1696247101,'month',4,8,10,1,0,0,0,0,'{"CONFIG": {"AUTOSUBMIT_VERSION": "4.0.95", "MAXWAITINGJOBS": 20, "TOTALJOBS": 20, "SAFETYSLEEPTIME": 10, "RETRIALS": 0}, "MAIL": {"NOTIFICATIONS": false, "TO": null}, "STORAGE": {"TYPE": "pkl", "COPY_REMOTE_LOGS": true}, "EXPERIMENT": {"DATELIST": 20220401, "MEMBERS": "fc0", "CHUNKSIZEUNIT": "month", "CHUNKSIZE": 4, "NUMCHUNKS": 2, "CHUNKINI": "", "CALENDAR": "standard"}, "PROJECT_FILES": {"FILE_PROJECT_CONF": "", "FILE_JOBS_CONF": "", "JOB_SCRIPTS_TYPE": ""}, "RERUN": {"RERUN": false, "RERUN_JOBLIST": ""}, "JOBS": {"LOCAL_SETUP": {"FILE": "templates/local_setup.sh", "PLATFORM": "LOCAL", "RUNNING": "once", "DEPENDENCIES": {}, "ADDITIONAL_FILES": []}, "SYNCHRONIZE": {"FILE": "templates/synchronize.sh", "PLATFORM": "LOCAL", "DEPENDENCIES": {"LOCAL_SETUP": {}}, "RUNNING": "once", "ADDITIONAL_FILES": []}, "REMOTE_SETUP": {"FILE": "templates/remote_setup.sh", "DEPENDENCIES": {"SYNCHRONIZE": {}}, "WALLCLOCK": "00:05", "RUNNING": "once", "ADDITIONAL_FILES": []}, "INI": {"FILE": "templates/ini.sh", "DEPENDENCIES": {"REMOTE_SETUP": {}}, "RUNNING": "member", "WALLCLOCK": "00:05", "ADDITIONAL_FILES": []}, "SIM": {"FILE": "templates/sim.sh", "DEPENDENCIES": {"INI": {}, "SIM-1": {}}, "RUNNING": "chunk", "WALLCLOCK": "00:05", "ADDITIONAL_FILES": []}, "POST": {"FILE": "templates/post.sh", "DEPENDENCIES": {"SIM": {}}, "RUNNING": "chunk", "WALLCLOCK": "00:05", "ADDITIONAL_FILES": []}, "CLEAN": {"FILE": "templates/clean.sh", "DEPENDENCIES": {"POST": {}}, "RUNNING": "chunk", "WALLCLOCK": "00:05", "ADDITIONAL_FILES": []}}, "PLATFORMS": {"MARENOSTRUM4": {"TYPE": "slurm", "HOST": "mn1.bsc.es", "PROJECT": "bsc32", "USER": "bsc32070", "QUEUE": "debug", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": false, "MAX_WALLCLOCK": "48:00", "TEMP_DIR": ""}, "MARENOSTRUM_ARCHIVE": {"TYPE": "ps", "HOST": "dt02.bsc.es", "PROJECT": "bsc32", "USER": "bsc32xxx", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": false, "TEST_SUITE": false}, "TRANSFER_NODE": {"TYPE": "ps", "HOST": "dt01.bsc.es", "PROJECT": "bsc32", "USER": "bsc32xxx", "ADD_PROJECT_TO_HOST": false, "SCRATCH_DIR": "/gpfs/scratch"}, "TRANSFER_NODE_BSCEARTH000": {"TYPE": "ps", "HOST": "bscearth000", "USER": "dbeltran", "PROJECT": "Earth", "ADD_PROJECT_TO_HOST": false, "QUEUE": "serial", "SCRATCH_DIR": "/esarchive/scratch"}, "BSCEARTH000": {"TYPE": "ps", "HOST": "bscearth000", "USER": "dbeltran", "PROJECT": "Earth", "ADD_PROJECT_TO_HOST": false, "QUEUE": "serial", "SCRATCH_DIR": "/esarchive/scratch"}, "NORD3": {"TYPE": "SLURM", "HOST": "nord1.bsc.es", "PROJECT": "bsc32", "USER": "bsc32xxx", "QUEUE": "debug", "SCRATCH_DIR": "/gpfs/scratch", "MAX_WALLCLOCK": "48:00"}, "ECMWF-XC40": {"TYPE": "ecaccess", "VERSION": "pbs", "HOST": "cca", "USER": "c3d", "PROJECT": "spesiccf", "ADD_PROJECT_TO_HOST": false, "SCRATCH_DIR": "/scratch/ms", "QUEUE": "np", "SERIAL_QUEUE": "ns", "MAX_WALLCLOCK": "48:00"}}, "ROOTDIR": "/home/dbeltran/new_autosubmit/a01o", "PROJDIR": "/home/dbeltran/new_autosubmit/a01o/proj/project_files", "DEFAULT": {"EXPID": "a01o", "HPCARCH": "marenostrum4", "CUSTOM_CONFIG": "/home/dbeltran/new_autosubmit/a01o/proj/git_project/as_conf"}, "PROJECT": {"PROJECT_TYPE": "git", "PROJECT_DESTINATION": "git_project"}, "GIT": {"PROJECT_ORIGIN": "https://earth.bsc.es/gitlab/dbeltran/edito-vanilla", "PROJECT_BRANCH": "main", "PROJECT_COMMIT": "", "PROJECT_SUBMODULES": "", "FETCH_SINGLE_BRANCH": true}}');
INSERT INTO experiment_run VALUES(15,'2023-10-02-13:45:01','2023-10-02-13:45:48',1696247101,1696247148,'month',4,0,10,0,0,0,0,0,'{"CONFIG": {"AUTOSUBMIT_VERSION": "4.0.95", "MAXWAITINGJOBS": 20, "TOTALJOBS": 20, "SAFETYSLEEPTIME": 10, "RETRIALS": 0}, "MAIL": {"NOTIFICATIONS": false, "TO": null}, "STORAGE": {"TYPE": "pkl", "COPY_REMOTE_LOGS": true}, "EXPERIMENT": {"DATELIST": 20220401, "MEMBERS": "fc0", "CHUNKSIZEUNIT": "month", "CHUNKSIZE": 4, "NUMCHUNKS": 2, "CHUNKINI": "", "CALENDAR": "standard"}, "PROJECT_FILES": {"FILE_PROJECT_CONF": "", "FILE_JOBS_CONF": "", "JOB_SCRIPTS_TYPE": ""}, "RERUN": {"RERUN": false, "RERUN_JOBLIST": ""}, "JOBS": {"LOCAL_SETUP": {"FILE": "templates/local_setup.sh", "PLATFORM": "LOCAL", "RUNNING": "once", "DEPENDENCIES": {}, "ADDITIONAL_FILES": []}, "SYNCHRONIZE": {"FILE": "templates/synchronize.sh", "PLATFORM": "LOCAL", "DEPENDENCIES": {"LOCAL_SETUP": {}}, "RUNNING": "once", "ADDITIONAL_FILES": []}, "REMOTE_SETUP": {"FILE": "templates/remote_setup.sh", "DEPENDENCIES": {"SYNCHRONIZE": {}}, "WALLCLOCK": "00:05", "RUNNING": "once", "ADDITIONAL_FILES": []}, "INI": {"FILE": "templates/ini.sh", "DEPENDENCIES": {"REMOTE_SETUP": {}}, "RUNNING": "member", "WALLCLOCK": "00:05", "ADDITIONAL_FILES": []}, "SIM": {"FILE": "templates/sim.sh", "DEPENDENCIES": {"INI": {}, "SIM-1": {}}, "RUNNING": "chunk", "WALLCLOCK": "00:05", "ADDITIONAL_FILES": []}, "POST": {"FILE": "templates/post.sh", "DEPENDENCIES": {"SIM": {}}, "RUNNING": "chunk", "WALLCLOCK": "00:05", "ADDITIONAL_FILES": []}, "CLEAN": {"FILE": "templates/clean.sh", "DEPENDENCIES": {"POST": {}}, "RUNNING": "chunk", "WALLCLOCK": "00:05", "ADDITIONAL_FILES": []}}, "PLATFORMS": {"MARENOSTRUM4": {"TYPE": "slurm", "HOST": "mn1.bsc.es", "PROJECT": "bsc32", "USER": "bsc32070", "QUEUE": "debug", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": false, "MAX_WALLCLOCK": "48:00", "TEMP_DIR": ""}, "MARENOSTRUM_ARCHIVE": {"TYPE": "ps", "HOST": "dt02.bsc.es", "PROJECT": "bsc32", "USER": "bsc32xxx", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": false, "TEST_SUITE": false}, "TRANSFER_NODE": {"TYPE": "ps", "HOST": "dt01.bsc.es", "PROJECT": "bsc32", "USER": "bsc32xxx", "ADD_PROJECT_TO_HOST": false, "SCRATCH_DIR": "/gpfs/scratch"}, "TRANSFER_NODE_BSCEARTH000": {"TYPE": "ps", "HOST": "bscearth000", "USER": "dbeltran", "PROJECT": "Earth", "ADD_PROJECT_TO_HOST": false, "QUEUE": "serial", "SCRATCH_DIR": "/esarchive/scratch"}, "BSCEARTH000": {"TYPE": "ps", "HOST": "bscearth000", "USER": "dbeltran", "PROJECT": "Earth", "ADD_PROJECT_TO_HOST": false, "QUEUE": "serial", "SCRATCH_DIR": "/esarchive/scratch"}, "NORD3": {"TYPE": "SLURM", "HOST": "nord1.bsc.es", "PROJECT": "bsc32", "USER": "bsc32xxx", "QUEUE": "debug", "SCRATCH_DIR": "/gpfs/scratch", "MAX_WALLCLOCK": "48:00"}, "ECMWF-XC40": {"TYPE": "ecaccess", "VERSION": "pbs", "HOST": "cca", "USER": "c3d", "PROJECT": "spesiccf", "ADD_PROJECT_TO_HOST": false, "SCRATCH_DIR": "/scratch/ms", "QUEUE": "np", "SERIAL_QUEUE": "ns", "MAX_WALLCLOCK": "48:00"}}, "ROOTDIR": "/home/dbeltran/new_autosubmit/a01o", "PROJDIR": "/home/dbeltran/new_autosubmit/a01o/proj/project_files", "DEFAULT": {"EXPID": "a01o", "HPCARCH": "marenostrum4", "CUSTOM_CONFIG": "/home/dbeltran/new_autosubmit/a01o/proj/git_project/as_conf"}, "PROJECT": {"PROJECT_TYPE": "git", "PROJECT_DESTINATION": "git_project"}, "GIT": {"PROJECT_ORIGIN": "https://earth.bsc.es/gitlab/dbeltran/edito-vanilla", "PROJECT_BRANCH": "main", "PROJECT_COMMIT": "", "PROJECT_SUBMODULES": "", "FETCH_SINGLE_BRANCH": true}}');
INSERT INTO experiment_run VALUES(16,'2023-10-02-13:45:48','2023-10-02-13:45:54',1696247148,1696247154,'month',4,0,8,0,0,0,0,0,'{"CONFIG": {"AUTOSUBMIT_VERSION": "4.0.95", "MAXWAITINGJOBS": 20, "TOTALJOBS": 20, "SAFETYSLEEPTIME": 10, "RETRIALS": 0}, "MAIL": {"NOTIFICATIONS": false, "TO": null}, "STORAGE": {"TYPE": "pkl", "COPY_REMOTE_LOGS": true}, "EXPERIMENT": {"DATELIST": 20220401, "MEMBERS": "fc0", "CHUNKSIZEUNIT": "month", "CHUNKSIZE": 4, "NUMCHUNKS": 2, "CHUNKINI": "", "CALENDAR": "standard"}, "PROJECT_FILES": {"FILE_PROJECT_CONF": "", "FILE_JOBS_CONF": "", "JOB_SCRIPTS_TYPE": ""}, "RERUN": {"RERUN": false, "RERUN_JOBLIST": ""}, "JOBS": {"LOCAL_SETUP": {"FILE": "templates/local_setup.sh", "PLATFORM": "LOCAL", "RUNNING": "once", "DEPENDENCIES": {}, "ADDITIONAL_FILES": []}, "SYNCHRONIZE": {"FILE": "templates/synchronize.sh", "PLATFORM": "LOCAL", "DEPENDENCIES": {"LOCAL_SETUP": {}}, "RUNNING": "once", "ADDITIONAL_FILES": []}, "REMOTE_SETUP": {"FILE": "templates/remote_setup.sh", "DEPENDENCIES": {"SYNCHRONIZE": {}}, "WALLCLOCK": "00:05", "RUNNING": "once", "ADDITIONAL_FILES": []}, "INI": {"FILE": "templates/ini.sh", "DEPENDENCIES": {"REMOTE_SETUP": {}}, "RUNNING": "member", "WALLCLOCK": "00:05", "ADDITIONAL_FILES": []}, "SIM": {"FILE": "templates/sim.sh", "DEPENDENCIES": {"INI": {}, "SIM-1": {}}, "RUNNING": "chunk", "WALLCLOCK": "00:05", "ADDITIONAL_FILES": []}, "POST": {"FILE": "templates/post.sh", "DEPENDENCIES": {"SIM": {}}, "RUNNING": "once", "WALLCLOCK": "00:05", "ADDITIONAL_FILES": []}, "CLEAN": {"FILE": "templates/clean.sh", "DEPENDENCIES": {"POST": {}}, "RUNNING": "once", "WALLCLOCK": "00:05", "ADDITIONAL_FILES": []}}, "PLATFORMS": {"MARENOSTRUM4": {"TYPE": "slurm", "HOST": "mn1.bsc.es", "PROJECT": "bsc32", "USER": "bsc32070", "QUEUE": "debug", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": false, "MAX_WALLCLOCK": "48:00", "TEMP_DIR": ""}, "MARENOSTRUM_ARCHIVE": {"TYPE": "ps", "HOST": "dt02.bsc.es", "PROJECT": "bsc32", "USER": "bsc32xxx", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": false, "TEST_SUITE": false}, "TRANSFER_NODE": {"TYPE": "ps", "HOST": "dt01.bsc.es", "PROJECT": "bsc32", "USER": "bsc32xxx", "ADD_PROJECT_TO_HOST": false, "SCRATCH_DIR": "/gpfs/scratch"}, "TRANSFER_NODE_BSCEARTH000": {"TYPE": "ps", "HOST": "bscearth000", "USER": "dbeltran", "PROJECT": "Earth", "ADD_PROJECT_TO_HOST": false, "QUEUE": "serial", "SCRATCH_DIR": "/esarchive/scratch"}, "BSCEARTH000": {"TYPE": "ps", "HOST": "bscearth000", "USER": "dbeltran", "PROJECT": "Earth", "ADD_PROJECT_TO_HOST": false, "QUEUE": "serial", "SCRATCH_DIR": "/esarchive/scratch"}, "NORD3": {"TYPE": "SLURM", "HOST": "nord1.bsc.es", "PROJECT": "bsc32", "USER": "bsc32xxx", "QUEUE": "debug", "SCRATCH_DIR": "/gpfs/scratch", "MAX_WALLCLOCK": "48:00"}, "ECMWF-XC40": {"TYPE": "ecaccess", "VERSION": "pbs", "HOST": "cca", "USER": "c3d", "PROJECT": "spesiccf", "ADD_PROJECT_TO_HOST": false, "SCRATCH_DIR": "/scratch/ms", "QUEUE": "np", "SERIAL_QUEUE": "ns", "MAX_WALLCLOCK": "48:00"}}, "ROOTDIR": "/home/dbeltran/new_autosubmit/a01o", "PROJDIR": "/home/dbeltran/new_autosubmit/a01o/proj/project_files", "DEFAULT": {"EXPID": "a01o", "HPCARCH": "marenostrum4", "CUSTOM_CONFIG": "/home/dbeltran/new_autosubmit/a01o/proj/git_project/as_conf"}, "PROJECT": {"PROJECT_TYPE": "git", "PROJECT_DESTINATION": "git_project"}, "GIT": {"PROJECT_ORIGIN": "https://earth.bsc.es/gitlab/dbeltran/edito-vanilla", "PROJECT_BRANCH": "main", "PROJECT_COMMIT": "", "PROJECT_SUBMODULES": "", "FETCH_SINGLE_BRANCH": true}}');
INSERT INTO experiment_run VALUES(17,'2023-10-02-13:45:54','2023-10-02-13:46:06',1696247154,1696247166,'month',4,0,8,0,0,0,0,0,'{"CONFIG": {"AUTOSUBMIT_VERSION": "4.0.95", "MAXWAITINGJOBS": 20, "TOTALJOBS": 20, "SAFETYSLEEPTIME": 10, "RETRIALS": 0}, "MAIL": {"NOTIFICATIONS": false, "TO": null}, "STORAGE": {"TYPE": "pkl", "COPY_REMOTE_LOGS": true}, "EXPERIMENT": {"DATELIST": 20220401, "MEMBERS": "fc0", "CHUNKSIZEUNIT": "month", "CHUNKSIZE": 4, "NUMCHUNKS": 2, "CHUNKINI": "", "CALENDAR": "standard"}, "PROJECT_FILES": {"FILE_PROJECT_CONF": "", "FILE_JOBS_CONF": "", "JOB_SCRIPTS_TYPE": ""}, "RERUN": {"RERUN": false, "RERUN_JOBLIST": ""}, "JOBS": {"LOCAL_SETUP": {"FILE": "templates/local_setup.sh", "PLATFORM": "LOCAL", "RUNNING": "once", "DEPENDENCIES": {}, "ADDITIONAL_FILES": []}, "SYNCHRONIZE": {"FILE": "templates/synchronize.sh", "PLATFORM": "LOCAL", "DEPENDENCIES": {"LOCAL_SETUP": {}}, "RUNNING": "once", "ADDITIONAL_FILES": []}, "REMOTE_SETUP": {"FILE": "templates/remote_setup.sh", "DEPENDENCIES": {"SYNCHRONIZE": {}}, "WALLCLOCK": "00:05", "RUNNING": "once", "ADDITIONAL_FILES": []}, "INI": {"FILE": "templates/ini.sh", "DEPENDENCIES": {"REMOTE_SETUP": {}}, "RUNNING": "member", "WALLCLOCK": "00:05", "ADDITIONAL_FILES": []}, "SIM": {"FILE": "templates/sim.sh", "DEPENDENCIES": {"INI": {}, "SIM-1": {}}, "RUNNING": "chunk", "WALLCLOCK": "00:05", "ADDITIONAL_FILES": []}, "POST": {"FILE": "templates/post.sh", "DEPENDENCIES": {"SIM": {}}, "RUNNING": "once", "WALLCLOCK": "00:05", "ADDITIONAL_FILES": []}, "CLEAN": {"FILE": "templates/clean.sh", "DEPENDENCIES": {"POST": {}}, "RUNNING": "once", "WALLCLOCK": "00:05", "ADDITIONAL_FILES": []}}, "PLATFORMS": {"MARENOSTRUM4": {"TYPE": "slurm", "HOST": "mn1.bsc.es", "PROJECT": "bsc32", "USER": "bsc32070", "QUEUE": "debug", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": false, "MAX_WALLCLOCK": "48:00", "TEMP_DIR": ""}, "MARENOSTRUM_ARCHIVE": {"TYPE": "ps", "HOST": "dt02.bsc.es", "PROJECT": "bsc32", "USER": "bsc32xxx", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": false, "TEST_SUITE": false}, "TRANSFER_NODE": {"TYPE": "ps", "HOST": "dt01.bsc.es", "PROJECT": "bsc32", "USER": "bsc32xxx", "ADD_PROJECT_TO_HOST": false, "SCRATCH_DIR": "/gpfs/scratch"}, "TRANSFER_NODE_BSCEARTH000": {"TYPE": "ps", "HOST": "bscearth000", "USER": "dbeltran", "PROJECT": "Earth", "ADD_PROJECT_TO_HOST": false, "QUEUE": "serial", "SCRATCH_DIR": "/esarchive/scratch"}, "BSCEARTH000": {"TYPE": "ps", "HOST": "bscearth000", "USER": "dbeltran", "PROJECT": "Earth", "ADD_PROJECT_TO_HOST": false, "QUEUE": "serial", "SCRATCH_DIR": "/esarchive/scratch"}, "NORD3": {"TYPE": "SLURM", "HOST": "nord1.bsc.es", "PROJECT": "bsc32", "USER": "bsc32xxx", "QUEUE": "debug", "SCRATCH_DIR": "/gpfs/scratch", "MAX_WALLCLOCK": "48:00"}, "ECMWF-XC40": {"TYPE": "ecaccess", "VERSION": "pbs", "HOST": "cca", "USER": "c3d", "PROJECT": "spesiccf", "ADD_PROJECT_TO_HOST": false, "SCRATCH_DIR": "/scratch/ms", "QUEUE": "np", "SERIAL_QUEUE": "ns", "MAX_WALLCLOCK": "48:00"}}, "ROOTDIR": "/home/dbeltran/new_autosubmit/a01o", "PROJDIR": "/home/dbeltran/new_autosubmit/a01o/proj/project_files", "DEFAULT": {"EXPID": "a01o", "HPCARCH": "marenostrum4", "CUSTOM_CONFIG": "/home/dbeltran/new_autosubmit/a01o/proj/git_project/as_conf"}, "PROJECT": {"PROJECT_TYPE": "git", "PROJECT_DESTINATION": "git_project"}, "GIT": {"PROJECT_ORIGIN": "https://earth.bsc.es/gitlab/dbeltran/edito-vanilla", "PROJECT_BRANCH": "main", "PROJECT_COMMIT": "", "PROJECT_SUBMODULES": "", "FETCH_SINGLE_BRANCH": true}}');
INSERT INTO experiment_run VALUES(18,'2023-10-02-13:46:06','2023-10-02-13:46:11',1696247166,1696247171,'month',4,0,8,0,0,0,0,0,'{"CONFIG": {"AUTOSUBMIT_VERSION": "4.0.95", "MAXWAITINGJOBS": 20, "TOTALJOBS": 20, "SAFETYSLEEPTIME": 10, "RETRIALS": 0}, "MAIL": {"NOTIFICATIONS": false, "TO": null}, "STORAGE": {"TYPE": "pkl", "COPY_REMOTE_LOGS": true}, "EXPERIMENT": {"DATELIST": 20220401, "MEMBERS": "fc0", "CHUNKSIZEUNIT": "month", "CHUNKSIZE": 4, "NUMCHUNKS": 2, "CHUNKINI": "", "CALENDAR": "standard"}, "PROJECT_FILES": {"FILE_PROJECT_CONF": "", "FILE_JOBS_CONF": "", "JOB_SCRIPTS_TYPE": ""}, "RERUN": {"RERUN": false, "RERUN_JOBLIST": ""}, "JOBS": {"LOCAL_SETUP": {"FILE": "templates/local_setup.sh", "PLATFORM": "LOCAL", "RUNNING": "once", "DEPENDENCIES": {}, "ADDITIONAL_FILES": []}, "SYNCHRONIZE": {"FILE": "templates/synchronize.sh", "PLATFORM": "LOCAL", "DEPENDENCIES": {"LOCAL_SETUP": {}}, "RUNNING": "once", "ADDITIONAL_FILES": []}, "REMOTE_SETUP": {"FILE": "templates/remote_setup.sh", "DEPENDENCIES": {"SYNCHRONIZE": {}}, "WALLCLOCK": "00:05", "RUNNING": "once", "ADDITIONAL_FILES": []}, "INI": {"FILE": "templates/ini.sh", "DEPENDENCIES": {"REMOTE_SETUP": {}}, "RUNNING": "member", "WALLCLOCK": "00:05", "ADDITIONAL_FILES": []}, "SIM": {"FILE": "templates/sim.sh", "DEPENDENCIES": {"INI": {}}, "RUNNING": "chunk", "WALLCLOCK": "00:05", "ADDITIONAL_FILES": []}, "POST": {"FILE": "templates/post.sh", "DEPENDENCIES": {"SIM": {}}, "RUNNING": "once", "WALLCLOCK": "00:05", "ADDITIONAL_FILES": []}, "CLEAN": {"FILE": "templates/clean.sh", "DEPENDENCIES": {"POST": {}}, "RUNNING": "once", "WALLCLOCK": "00:05", "ADDITIONAL_FILES": []}}, "PLATFORMS": {"MARENOSTRUM4": {"TYPE": "slurm", "HOST": "mn1.bsc.es", "PROJECT": "bsc32", "USER": "bsc32070", "QUEUE": "debug", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": false, "MAX_WALLCLOCK": "48:00", "TEMP_DIR": ""}, "MARENOSTRUM_ARCHIVE": {"TYPE": "ps", "HOST": "dt02.bsc.es", "PROJECT": "bsc32", "USER": "bsc32xxx", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": false, "TEST_SUITE": false}, "TRANSFER_NODE": {"TYPE": "ps", "HOST": "dt01.bsc.es", "PROJECT": "bsc32", "USER": "bsc32xxx", "ADD_PROJECT_TO_HOST": false, "SCRATCH_DIR": "/gpfs/scratch"}, "TRANSFER_NODE_BSCEARTH000": {"TYPE": "ps", "HOST": "bscearth000", "USER": "dbeltran", "PROJECT": "Earth", "ADD_PROJECT_TO_HOST": false, "QUEUE": "serial", "SCRATCH_DIR": "/esarchive/scratch"}, "BSCEARTH000": {"TYPE": "ps", "HOST": "bscearth000", "USER": "dbeltran", "PROJECT": "Earth", "ADD_PROJECT_TO_HOST": false, "QUEUE": "serial", "SCRATCH_DIR": "/esarchive/scratch"}, "NORD3": {"TYPE": "SLURM", "HOST": "nord1.bsc.es", "PROJECT": "bsc32", "USER": "bsc32xxx", "QUEUE": "debug", "SCRATCH_DIR": "/gpfs/scratch", "MAX_WALLCLOCK": "48:00"}, "ECMWF-XC40": {"TYPE": "ecaccess", "VERSION": "pbs", "HOST": "cca", "USER": "c3d", "PROJECT": "spesiccf", "ADD_PROJECT_TO_HOST": false, "SCRATCH_DIR": "/scratch/ms", "QUEUE": "np", "SERIAL_QUEUE": "ns", "MAX_WALLCLOCK": "48:00"}}, "ROOTDIR": "/home/dbeltran/new_autosubmit/a01o", "PROJDIR": "/home/dbeltran/new_autosubmit/a01o/proj/project_files", "DEFAULT": {"EXPID": "a01o", "HPCARCH": "marenostrum4", "CUSTOM_CONFIG": "/home/dbeltran/new_autosubmit/a01o/proj/git_project/as_conf"}, "PROJECT": {"PROJECT_TYPE": "git", "PROJECT_DESTINATION": "git_project"}, "GIT": {"PROJECT_ORIGIN": "https://earth.bsc.es/gitlab/dbeltran/edito-vanilla", "PROJECT_BRANCH": "main", "PROJECT_COMMIT": "", "PROJECT_SUBMODULES": "", "FETCH_SINGLE_BRANCH": true}}');
INSERT INTO experiment_run VALUES(19,'2023-10-02-13:46:11','2023-10-02-14:43:19',1696247171,1696250599,'month',4,8,8,0,0,0,0,0,'{"CONFIG": {"AUTOSUBMIT_VERSION": "4.0.95", "MAXWAITINGJOBS": 20, "TOTALJOBS": 20, "SAFETYSLEEPTIME": 10, "RETRIALS": 0}, "MAIL": {"NOTIFICATIONS": false, "TO": null}, "STORAGE": {"TYPE": "pkl", "COPY_REMOTE_LOGS": true}, "EXPERIMENT": {"DATELIST": 20220401, "MEMBERS": "fc0", "CHUNKSIZEUNIT": "month", "CHUNKSIZE": 4, "NUMCHUNKS": 2, "CHUNKINI": "", "CALENDAR": "standard"}, "PROJECT_FILES": {"FILE_PROJECT_CONF": "", "FILE_JOBS_CONF": "", "JOB_SCRIPTS_TYPE": ""}, "RERUN": {"RERUN": false, "RERUN_JOBLIST": ""}, "JOBS": {"LOCAL_SETUP": {"FILE": "templates/local_setup.sh", "PLATFORM": "LOCAL", "RUNNING": "once", "DEPENDENCIES": {}, "ADDITIONAL_FILES": []}, "SYNCHRONIZE": {"FILE": "templates/synchronize.sh", "PLATFORM": "LOCAL", "DEPENDENCIES": {"LOCAL_SETUP": {}}, "RUNNING": "once", "ADDITIONAL_FILES": []}, "REMOTE_SETUP": {"FILE": "templates/remote_setup.sh", "DEPENDENCIES": {"SYNCHRONIZE": {}}, "WALLCLOCK": "00:05", "RUNNING": "once", "ADDITIONAL_FILES": []}, "INI": {"FILE": "templates/ini.sh", "DEPENDENCIES": {"REMOTE_SETUP": {}}, "RUNNING": "member", "WALLCLOCK": "00:05", "ADDITIONAL_FILES": []}, "SIM": {"FILE": "templates/sim.sh", "DEPENDENCIES": {"INI": {}}, "RUNNING": "chunk", "WALLCLOCK": "00:05", "ADDITIONAL_FILES": []}, "POST": {"FILE": "templates/post.sh", "DEPENDENCIES": {"SIM": {}}, "RUNNING": "once", "WALLCLOCK": "00:05", "ADDITIONAL_FILES": []}, "CLEAN": {"FILE": "templates/clean.sh", "DEPENDENCIES": {"POST": {}}, "RUNNING": "once", "WALLCLOCK": "00:05", "ADDITIONAL_FILES": []}}, "PLATFORMS": {"MARENOSTRUM4": {"TYPE": "slurm", "HOST": "mn1.bsc.es", "PROJECT": "bsc32", "USER": "bsc32070", "QUEUE": "debug", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": false, "MAX_WALLCLOCK": "48:00", "TEMP_DIR": ""}, "MARENOSTRUM_ARCHIVE": {"TYPE": "ps", "HOST": "dt02.bsc.es", "PROJECT": "bsc32", "USER": "bsc32xxx", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": false, "TEST_SUITE": false}, "TRANSFER_NODE": {"TYPE": "ps", "HOST": "dt01.bsc.es", "PROJECT": "bsc32", "USER": "bsc32xxx", "ADD_PROJECT_TO_HOST": false, "SCRATCH_DIR": "/gpfs/scratch"}, "TRANSFER_NODE_BSCEARTH000": {"TYPE": "ps", "HOST": "bscearth000", "USER": "dbeltran", "PROJECT": "Earth", "ADD_PROJECT_TO_HOST": false, "QUEUE": "serial", "SCRATCH_DIR": "/esarchive/scratch"}, "BSCEARTH000": {"TYPE": "ps", "HOST": "bscearth000", "USER": "dbeltran", "PROJECT": "Earth", "ADD_PROJECT_TO_HOST": false, "QUEUE": "serial", "SCRATCH_DIR": "/esarchive/scratch"}, "NORD3": {"TYPE": "SLURM", "HOST": "nord1.bsc.es", "PROJECT": "bsc32", "USER": "bsc32xxx", "QUEUE": "debug", "SCRATCH_DIR": "/gpfs/scratch", "MAX_WALLCLOCK": "48:00"}, "ECMWF-XC40": {"TYPE": "ecaccess", "VERSION": "pbs", "HOST": "cca", "USER": "c3d", "PROJECT": "spesiccf", "ADD_PROJECT_TO_HOST": false, "SCRATCH_DIR": "/scratch/ms", "QUEUE": "np", "SERIAL_QUEUE": "ns", "MAX_WALLCLOCK": "48:00"}}, "ROOTDIR": "/home/dbeltran/new_autosubmit/a01o", "PROJDIR": "/home/dbeltran/new_autosubmit/a01o/proj/project_files", "DEFAULT": {"EXPID": "a01o", "HPCARCH": "marenostrum4", "CUSTOM_CONFIG": "/home/dbeltran/new_autosubmit/a01o/proj/git_project/as_conf"}, "PROJECT": {"PROJECT_TYPE": "git", "PROJECT_DESTINATION": "git_project"}, "GIT": {"PROJECT_ORIGIN": "https://earth.bsc.es/gitlab/dbeltran/edito-vanilla", "PROJECT_BRANCH": "main", "PROJECT_COMMIT": "", "PROJECT_SUBMODULES": "", "FETCH_SINGLE_BRANCH": true}}');
INSERT INTO experiment_run VALUES(20,'2023-10-02-14:43:19','2023-10-02-14:43:19',1696250599,0,'month',4,0,8,0,0,0,0,0,'{"CONFIG": {"AUTOSUBMIT_VERSION": "4.0.95", "MAXWAITINGJOBS": 20, "TOTALJOBS": 20, "SAFETYSLEEPTIME": 10, "RETRIALS": 0}, "MAIL": {"NOTIFICATIONS": false, "TO": null}, "STORAGE": {"TYPE": "pkl", "COPY_REMOTE_LOGS": true}, "EXPERIMENT": {"DATELIST": 20220401, "MEMBERS": "fc0", "CHUNKSIZEUNIT": "month", "CHUNKSIZE": 4, "NUMCHUNKS": 2, "CHUNKINI": "", "CALENDAR": "standard"}, "PROJECT_FILES": {"FILE_PROJECT_CONF": "", "FILE_JOBS_CONF": "", "JOB_SCRIPTS_TYPE": ""}, "RERUN": {"RERUN": false, "RERUN_JOBLIST": ""}, "JOBS": {"LOCAL_SETUP": {"FILE": "templates/local_setup.sh", "PLATFORM": "LOCAL", "RUNNING": "once", "DEPENDENCIES": {}, "ADDITIONAL_FILES": []}, "SYNCHRONIZE": {"FILE": "templates/synchronize.sh", "PLATFORM": "LOCAL", "DEPENDENCIES": {"LOCAL_SETUP": {}}, "RUNNING": "once", "ADDITIONAL_FILES": []}, "REMOTE_SETUP": {"FILE": "templates/remote_setup.sh", "DEPENDENCIES": {"SYNCHRONIZE": {}}, "WALLCLOCK": "00:05", "RUNNING": "once", "ADDITIONAL_FILES": []}, "INI": {"FILE": "templates/ini.sh", "DEPENDENCIES": {"REMOTE_SETUP": {}}, "RUNNING": "member", "WALLCLOCK": "00:05", "ADDITIONAL_FILES": []}, "SIM": {"FILE": "templates/sim.sh", "DEPENDENCIES": {"INI": {}}, "RUNNING": "chunk", "WALLCLOCK": "00:05", "ADDITIONAL_FILES": []}, "POST": {"FILE": "templates/post.sh", "DEPENDENCIES": {"SIM": {}}, "RUNNING": "once", "WALLCLOCK": "00:05", "ADDITIONAL_FILES": []}, "CLEAN": {"FILE": "templates/clean.sh", "DEPENDENCIES": {"POST": {}}, "RUNNING": "once", "WALLCLOCK": "00:05", "ADDITIONAL_FILES": []}}, "PLATFORMS": {"MARENOSTRUM4": {"TYPE": "slurm", "HOST": "mn1.bsc.es", "PROJECT": "bsc32", "USER": "bsc32070", "QUEUE": "debug", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": false, "MAX_WALLCLOCK": "48:00", "TEMP_DIR": ""}, "MARENOSTRUM_ARCHIVE": {"TYPE": "ps", "HOST": "dt02.bsc.es", "PROJECT": "bsc32", "USER": "bsc32xxx", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": false, "TEST_SUITE": false}, "TRANSFER_NODE": {"TYPE": "ps", "HOST": "dt01.bsc.es", "PROJECT": "bsc32", "USER": "bsc32xxx", "ADD_PROJECT_TO_HOST": false, "SCRATCH_DIR": "/gpfs/scratch"}, "TRANSFER_NODE_BSCEARTH000": {"TYPE": "ps", "HOST": "bscearth000", "USER": "dbeltran", "PROJECT": "Earth", "ADD_PROJECT_TO_HOST": false, "QUEUE": "serial", "SCRATCH_DIR": "/esarchive/scratch"}, "BSCEARTH000": {"TYPE": "ps", "HOST": "bscearth000", "USER": "dbeltran", "PROJECT": "Earth", "ADD_PROJECT_TO_HOST": false, "QUEUE": "serial", "SCRATCH_DIR": "/esarchive/scratch"}, "NORD3": {"TYPE": "SLURM", "HOST": "nord1.bsc.es", "PROJECT": "bsc32", "USER": "bsc32xxx", "QUEUE": "debug", "SCRATCH_DIR": "/gpfs/scratch", "MAX_WALLCLOCK": "48:00"}, "ECMWF-XC40": {"TYPE": "ecaccess", "VERSION": "pbs", "HOST": "cca", "USER": "c3d", "PROJECT": "spesiccf", "ADD_PROJECT_TO_HOST": false, "SCRATCH_DIR": "/scratch/ms", "QUEUE": "np", "SERIAL_QUEUE": "ns", "MAX_WALLCLOCK": "48:00"}}, "ROOTDIR": "/home/dbeltran/new_autosubmit/a01o", "PROJDIR": "/home/dbeltran/new_autosubmit/a01o/proj/project_files", "DEFAULT": {"EXPID": "a01o", "HPCARCH": "marenostrum4", "CUSTOM_CONFIG": "/home/dbeltran/new_autosubmit/a01o/proj/git_project/as_conf"}, "PROJECT": {"PROJECT_TYPE": "git", "PROJECT_DESTINATION": "git_project"}, "GIT": {"PROJECT_ORIGIN": "https://earth.bsc.es/gitlab/dbeltran/edito-vanilla", "PROJECT_BRANCH": "main", "PROJECT_COMMIT": "", "PROJECT_SUBMODULES": "", "FETCH_SINGLE_BRANCH": true}}');
CREATE TABLE job_data (
      id INTEGER NOT NULL PRIMARY KEY AUTOINCREMENT,
      counter INTEGER NOT NULL,
      job_name TEXT NOT NULL,
      created TEXT NOT NULL,
      modified TEXT NOT NULL,
      submit INTEGER NOT NULL,
      start INTEGER NOT NULL,
      finish INTEGER NOT NULL,
      status TEXT NOT NULL,
      rowtype INTEGER NOT NULL,
      ncpus INTEGER NOT NULL,
      wallclock TEXT NOT NULL,
      qos TEXT NOT NULL,
      energy INTEGER NOT NULL,
      date TEXT NOT NULL,
      section TEXT NOT NULL,
      member TEXT NOT NULL,
      chunk INTEGER NOT NULL,
      last INTEGER NOT NULL,
      platform TEXT NOT NULL,
      job_id INTEGER NOT NULL,
      extra_data TEXT NOT NULL,
      nnodes INTEGER NOT NULL DEFAULT 0,
      run_id INTEGER,
      MaxRSS REAL NOT NULL DEFAULT 0.0,
      AveRSS REAL NOT NULL DEFAULT 0.0,
      out TEXT NOT NULL,
      err TEXT NOT NULL,
      rowstatus INTEGER NOT NULL DEFAULT 0,
      children TEXT,
      platform_output TEXT,
      UNIQUE(counter,job_name)
      );
INSERT INTO job_data VALUES(1,0,'a01o_LOCAL_SETUP','2023-10-02-12:56:09','2023-10-02-13:08:03',1696244169,1696244169,1696244174,'COMPLETED',2,1,'00:00','debug',0,'','LOCAL_SETUP','',0,0,'LOCAL',28087,'',0,5,0.0,0.0,'a01o_LOCAL_SETUP.20231002125621.out','a01o_LOCAL_SETUP.20231002125621.err',5,'a01o_SYNCHRONIZE','');
INSERT INTO job_data VALUES(2,0,'a01o_SYNCHRONIZE','2023-10-02-12:56:21','2023-10-02-13:08:15',1696244181,1696244181,1696244186,'COMPLETED',2,1,'00:00','debug',0,'','SYNCHRONIZE','',0,0,'LOCAL',28124,'',0,5,0.0,0.0,'a01o_SYNCHRONIZE.20231002125633.out','a01o_SYNCHRONIZE.20231002125633.err',5,'a01o_REMOTE_SETUP','');
INSERT INTO job_data VALUES(3,0,'a01o_REMOTE_SETUP','2023-10-02-12:56:34','2023-10-02-13:08:27',1696244194,1696244194,1696244199,'COMPLETED',2,1,'00:05','debug',0,'','REMOTE_SETUP','',0,0,'LOCAL',28159,'',0,5,0.0,0.0,'a01o_REMOTE_SETUP.20231002125646.out','a01o_REMOTE_SETUP.20231002125646.err',5,'a01o_20220401_fc0_INI','');
INSERT INTO job_data VALUES(4,0,'a01o_20220401_fc0_INI','2023-10-02-12:56:46','2023-10-02-13:08:40',1696244206,1696244206,1696244211,'COMPLETED',2,1,'00:05','debug',0,'2022-04-01 00:00:00','INI','fc0',0,0,'LOCAL',28199,'',0,5,0.0,0.0,'a01o_20220401_fc0_INI.20231002125658.out','a01o_20220401_fc0_INI.20231002125658.err',5,'a01o_20220401_fc0_1_SIM','');
INSERT INTO job_data VALUES(5,0,'a01o_20220401_fc0_1_SIM','2023-10-02-12:56:58','2023-10-02-13:08:52',1696244218,1696244218,1696244223,'COMPLETED',2,1,'00:05','debug',0,'2022-04-01 00:00:00','SIM','fc0',1,0,'LOCAL',28236,'',0,5,0.0,0.0,'a01o_20220401_fc0_1_SIM.20231002125710.out','a01o_20220401_fc0_1_SIM.20231002125710.err',5,'a01o_20220401_fc0_2_SIM,a01o_20220401_fc0_1_POST','');
INSERT INTO job_data VALUES(6,0,'a01o_20220401_fc0_1_POST','2023-10-02-12:57:10','2023-10-02-13:09:04',1696244230,1696244230,1696244235,'COMPLETED',2,1,'00:05','debug',0,'2022-04-01 00:00:00','POST','fc0',1,0,'LOCAL',28275,'',0,5,0.0,0.0,'a01o_20220401_fc0_1_POST.20231002125725.out','a01o_20220401_fc0_1_POST.20231002125725.err',5,'a01o_20220401_fc0_1_CLEAN','');
INSERT INTO job_data VALUES(7,0,'a01o_20220401_fc0_2_SIM','2023-10-02-12:57:10','2023-10-02-13:09:04',1696244230,1696244230,1696244235,'COMPLETED',2,1,'00:05','debug',0,'2022-04-01 00:00:00','SIM','fc0',2,0,'LOCAL',28298,'',0,5,0.0,0.0,'a01o_20220401_fc0_2_SIM.20231002125724.out','a01o_20220401_fc0_2_SIM.20231002125724.err',5,'a01o_20220401_fc0_2_POST','');
INSERT INTO job_data VALUES(8,0,'a01o_20220401_fc0_1_CLEAN','2023-10-02-12:57:25','2023-10-02-13:09:19',1696244245,1696244245,1696244250,'COMPLETED',2,1,'00:05','debug',0,'2022-04-01 00:00:00','CLEAN','fc0',1,0,'LOCAL',28351,'',0,5,0.0,0.0,'a01o_20220401_fc0_1_CLEAN.20231002125739.out','a01o_20220401_fc0_1_CLEAN.20231002125739.err',5,'','');
INSERT INTO job_data VALUES(9,0,'a01o_20220401_fc0_2_POST','2023-10-02-12:57:25','2023-10-02-13:09:19',1696244245,1696244245,1696244250,'COMPLETED',2,1,'00:05','debug',0,'2022-04-01 00:00:00','POST','fc0',2,0,'LOCAL',28374,'',0,5,0.0,0.0,'a01o_20220401_fc0_2_POST.20231002125739.out','a01o_20220401_fc0_2_POST.20231002125739.err',5,'a01o_20220401_fc0_2_CLEAN','');
INSERT INTO job_data VALUES(10,0,'a01o_20220401_fc0_2_CLEAN','2023-10-02-12:57:39','2023-10-02-13:09:33',1696244259,1696244259,1696244264,'COMPLETED',2,1,'00:05','debug',0,'2022-04-01 00:00:00','CLEAN','fc0',2,0,'LOCAL',28423,'',0,5,0.0,0.0,'a01o_20220401_fc0_2_CLEAN.20231002125751.out','a01o_20220401_fc0_2_CLEAN.20231002125751.err',5,'','');
INSERT INTO job_data VALUES(11,1,'a01o_LOCAL_SETUP','2023-10-02-13:08:03','2023-10-02-13:14:32',1696244883,1696244883,1696244888,'COMPLETED',2,1,'00:00','debug',0,'','LOCAL_SETUP','',0,0,'LOCAL',28842,'',0,6,0.0,0.0,'a01o_LOCAL_SETUP.20231002130815.out','a01o_LOCAL_SETUP.20231002130815.err',5,'a01o_SYNCHRONIZE','');
INSERT INTO job_data VALUES(12,1,'a01o_SYNCHRONIZE','2023-10-02-13:08:15','2023-10-02-13:14:44',1696244895,1696244895,1696244900,'COMPLETED',2,1,'00:00','debug',0,'','SYNCHRONIZE','',0,0,'LOCAL',28876,'',0,6,0.0,0.0,'a01o_SYNCHRONIZE.20231002130827.out','a01o_SYNCHRONIZE.20231002130827.err',5,'a01o_REMOTE_SETUP','');
INSERT INTO job_data VALUES(13,1,'a01o_REMOTE_SETUP','2023-10-02-13:08:28','2023-10-02-13:14:56',1696244907,1696244908,1696244913,'COMPLETED',2,1,'00:05','debug',0,'','REMOTE_SETUP','',0,0,'LOCAL',28920,'',0,6,0.0,0.0,'a01o_REMOTE_SETUP.20231002130840.out','a01o_REMOTE_SETUP.20231002130840.err',5,'a01o_20220401_fc0_INI','');
INSERT INTO job_data VALUES(14,1,'a01o_20220401_fc0_INI','2023-10-02-13:08:40','2023-10-02-13:15:09',1696244920,1696244920,1696244925,'COMPLETED',2,1,'00:05','debug',0,'2022-04-01 00:00:00','INI','fc0',0,0,'LOCAL',28992,'',0,6,0.0,0.0,'a01o_20220401_fc0_INI.20231002130852.out','a01o_20220401_fc0_INI.20231002130852.err',5,'a01o_20220401_fc0_1_SIM','');
INSERT INTO job_data VALUES(15,1,'a01o_20220401_fc0_1_SIM','2023-10-02-13:08:52','2023-10-02-13:15:21',1696244932,1696244932,1696244937,'COMPLETED',2,1,'00:05','debug',0,'2022-04-01 00:00:00','SIM','fc0',1,0,'LOCAL',29041,'',0,6,0.0,0.0,'a01o_20220401_fc0_1_SIM.20231002130904.out','a01o_20220401_fc0_1_SIM.20231002130904.err',5,'a01o_20220401_fc0_2_SIM,a01o_20220401_fc0_1_POST','');
INSERT INTO job_data VALUES(16,1,'a01o_20220401_fc0_1_POST','2023-10-02-13:09:04','2023-10-02-13:15:33',1696244944,1696244944,1696244949,'COMPLETED',2,1,'00:05','debug',0,'2022-04-01 00:00:00','POST','fc0',1,0,'LOCAL',29079,'',0,6,0.0,0.0,'a01o_20220401_fc0_1_POST.20231002130919.out','a01o_20220401_fc0_1_POST.20231002130919.err',5,'a01o_20220401_fc0_1_CLEAN','');
INSERT INTO job_data VALUES(17,1,'a01o_20220401_fc0_2_SIM','2023-10-02-13:09:04','2023-10-02-13:15:33',1696244944,1696244944,1696244949,'COMPLETED',2,1,'00:05','debug',0,'2022-04-01 00:00:00','SIM','fc0',2,0,'LOCAL',29102,'',0,6,0.0,0.0,'a01o_20220401_fc0_2_SIM.20231002130918.out','a01o_20220401_fc0_2_SIM.20231002130918.err',5,'a01o_20220401_fc0_2_POST','');
INSERT INTO job_data VALUES(18,1,'a01o_20220401_fc0_1_CLEAN','2023-10-02-13:09:19','2023-10-02-13:36:29',1696244959,1696244959,1696244964,'COMPLETED',2,1,'00:05','debug',0,'2022-04-01 00:00:00','CLEAN','fc0',1,0,'LOCAL',29151,'',0,6,0.0,0.0,'a01o_20220401_fc0_1_CLEAN.20231002130933.out','a01o_20220401_fc0_1_CLEAN.20231002130933.err',5,'','');
INSERT INTO job_data VALUES(19,1,'a01o_20220401_fc0_2_POST','2023-10-02-13:09:19','2023-10-02-13:38:25',1696244959,1696244959,1696244964,'COMPLETED',2,1,'00:05','debug',0,'2022-04-01 00:00:00','POST','fc0',2,0,'LOCAL',29174,'',0,6,0.0,0.0,'a01o_20220401_fc0_2_POST.20231002130933.out','a01o_20220401_fc0_2_POST.20231002130933.err',5,'a01o_20220401_fc0_2_CLEAN','');
INSERT INTO job_data VALUES(20,1,'a01o_20220401_fc0_2_CLEAN','2023-10-02-13:09:33','2023-10-02-13:09:45',1696244973,1696244973,1696244978,'COMPLETED',2,1,'00:05','debug',0,'2022-04-01 00:00:00','CLEAN','fc0',2,1,'LOCAL',29223,'',0,6,0.0,0.0,'a01o_20220401_fc0_2_CLEAN.20231002130945.out','a01o_20220401_fc0_2_CLEAN.20231002130945.err',5,'','');
INSERT INTO job_data VALUES(21,2,'a01o_LOCAL_SETUP','2023-10-02-13:14:32','2023-10-02-13:22:18',1696245272,1696245272,1696245277,'COMPLETED',2,1,'00:00','debug',0,'','LOCAL_SETUP','',0,0,'LOCAL',29516,'',0,7,0.0,0.0,'a01o_LOCAL_SETUP.20231002131444.out','a01o_LOCAL_SETUP.20231002131444.err',5,'a01o_SYNCHRONIZE','');
INSERT INTO job_data VALUES(22,2,'a01o_SYNCHRONIZE','2023-10-02-13:14:44','2023-10-02-13:22:30',1696245284,1696245284,1696245289,'COMPLETED',2,1,'00:00','debug',0,'','SYNCHRONIZE','',0,0,'LOCAL',29550,'',0,7,0.0,0.0,'a01o_SYNCHRONIZE.20231002131456.out','a01o_SYNCHRONIZE.20231002131456.err',5,'a01o_REMOTE_SETUP','');
INSERT INTO job_data VALUES(23,2,'a01o_REMOTE_SETUP','2023-10-02-13:14:56','2023-10-02-13:29:28',1696245296,1696245296,1696245301,'COMPLETED',2,1,'00:05','debug',0,'','REMOTE_SETUP','',0,0,'LOCAL',29586,'',0,7,0.0,0.0,'a01o_REMOTE_SETUP.20231002131508.out','a01o_REMOTE_SETUP.20231002131508.err',5,'a01o_20220401_fc0_INI','');
INSERT INTO job_data VALUES(24,2,'a01o_20220401_fc0_INI','2023-10-02-13:15:09','2023-10-02-13:30:39',1696245309,1696245309,1696245314,'COMPLETED',2,1,'00:05','debug',0,'2022-04-01 00:00:00','INI','fc0',0,0,'LOCAL',29649,'',0,7,0.0,0.0,'a01o_20220401_fc0_INI.20231002131521.out','a01o_20220401_fc0_INI.20231002131521.err',5,'a01o_20220401_fc0_1_SIM','');
INSERT INTO job_data VALUES(25,2,'a01o_20220401_fc0_1_SIM','2023-10-02-13:15:21','2023-10-02-13:32:34',1696245321,1696245321,1696245326,'COMPLETED',2,1,'00:05','debug',0,'2022-04-01 00:00:00','SIM','fc0',1,0,'LOCAL',29699,'',0,7,0.0,0.0,'a01o_20220401_fc0_1_SIM.20231002131533.out','a01o_20220401_fc0_1_SIM.20231002131533.err',5,'a01o_20220401_fc0_2_SIM,a01o_20220401_fc0_1_POST','');
INSERT INTO job_data VALUES(26,2,'a01o_20220401_fc0_1_POST','2023-10-02-13:15:33','2023-10-02-13:34:32',1696245333,0,0,'SUBMITTED',2,1,'00:05','debug',0,'2022-04-01 00:00:00','POST','fc0',1,0,'LOCAL',29735,'',0,7,0.0,0.0,'','',0,'a01o_20220401_fc0_1_CLEAN','');
INSERT INTO job_data VALUES(27,2,'a01o_20220401_fc0_2_SIM','2023-10-02-13:15:33','2023-10-02-13:34:32',1696245333,0,0,'SUBMITTED',2,1,'00:05','debug',0,'2022-04-01 00:00:00','SIM','fc0',2,0,'LOCAL',29758,'',0,7,0.0,0.0,'','',0,'a01o_20220401_fc0_2_POST','');
INSERT INTO job_data VALUES(28,3,'a01o_LOCAL_SETUP','2023-10-02-13:22:18','2023-10-02-13:28:56',1696245738,1696245738,1696245738,'COMPLETED',2,1,'00:00','debug',0,'','LOCAL_SETUP','',0,0,'LOCAL',30899,'',0,12,0.0,0.0,'a01o_LOCAL_SETUP.20231002132230.out','a01o_LOCAL_SETUP.20231002132230.err',5,'a01o_SYNCHRONIZE','');
INSERT INTO job_data VALUES(29,3,'a01o_SYNCHRONIZE','2023-10-02-13:22:30','2023-10-02-13:29:08',1696245750,0,0,'SUBMITTED',2,1,'00:00','debug',0,'','SYNCHRONIZE','',0,0,'LOCAL',30935,'',0,12,0.0,0.0,'','',0,'a01o_REMOTE_SETUP','');
INSERT INTO job_data VALUES(30,4,'a01o_LOCAL_SETUP','2023-10-02-13:28:56','2023-10-02-13:45:09',1696246136,1696246136,1696246136,'COMPLETED',2,1,'00:00','debug',0,'','LOCAL_SETUP','',0,0,'LOCAL',31429,'',0,14,0.0,0.0,'a01o_LOCAL_SETUP.20231002132908.out','a01o_LOCAL_SETUP.20231002132908.err',5,'a01o_SYNCHRONIZE','');
INSERT INTO job_data VALUES(31,4,'a01o_SYNCHRONIZE','2023-10-02-13:29:09','2023-10-02-13:46:29',1696246148,1696246148,1696246153,'COMPLETED',2,1,'00:00','debug',0,'','SYNCHRONIZE','',0,0,'LOCAL',31469,'',0,14,0.0,0.0,'a01o_SYNCHRONIZE.20231002132921.out','a01o_SYNCHRONIZE.20231002132921.err',5,'a01o_REMOTE_SETUP','');
INSERT INTO job_data VALUES(32,4,'a01o_REMOTE_SETUP','2023-10-02-13:29:28','2023-10-02-13:46:46',1696246168,1696246227,1696246227,'COMPLETED',2,1,'00:05','debug',335,'','REMOTE_SETUP','',0,0,'MARENOSTRUM4',30303812,'',1,14,0.0,0.0,'a01o_REMOTE_SETUP.20231002133033.out','a01o_REMOTE_SETUP.20231002133033.err',2,'a01o_20220401_fc0_INI',replace('                 30303812  COMPLETED          1        1 2023-10-02T13:29:28 2023-10-02T13:30:24 2023-10-02T13:30:29            335                                                     \n           30303812.batch  COMPLETED          1        1 2023-10-02T13:30:24 2023-10-02T13:30:24 2023-10-02T13:30:29             25                      953K                      953K \n          30303812.extern  COMPLETED          1        1 2023-10-02T13:30:24 2023-10-02T13:30:24 2023-10-02T13:30:29            335                      704K                      704K \n','\n',char(10)));
INSERT INTO job_data VALUES(33,4,'a01o_20220401_fc0_INI','2023-10-02-13:30:39','2023-10-02-13:48:34',1696246239,1696246345,1696246345,'COMPLETED',2,1,'00:05','debug',247,'2022-04-01 00:00:00','INI','fc0',0,0,'MARENOSTRUM4',30303819,'',1,14,0.0,0.0,'a01o_20220401_fc0_INI.20231002133229.out','a01o_20220401_fc0_INI.20231002133229.err',2,'a01o_20220401_fc0_1_SIM',replace('                 30303819  COMPLETED          1        1 2023-10-02T13:30:39 2023-10-02T13:32:20 2023-10-02T13:32:27            247                                                     \n           30303819.batch  COMPLETED          1        1 2023-10-02T13:32:20 2023-10-02T13:32:20 2023-10-02T13:32:27             21                     1018K                     1018K \n          30303819.extern  COMPLETED          1        1 2023-10-02T13:32:20 2023-10-02T13:32:20 2023-10-02T13:32:27            247                      704K                      704K \n','\n',char(10)));
INSERT INTO job_data VALUES(34,4,'a01o_20220401_fc0_1_SIM','2023-10-02-13:32:34','2023-10-02-13:50:46',1696246354,1696246458,1696246458,'COMPLETED',2,1,'00:05','debug',256,'2022-04-01 00:00:00','SIM','fc0',1,0,'MARENOSTRUM4',30303827,'',1,14,0.0,0.0,'a01o_20220401_fc0_1_SIM.20231002133428.out','a01o_20220401_fc0_1_SIM.20231002133428.err',2,'a01o_20220401_fc0_2_SIM,a01o_20220401_fc0_1_POST',replace('                 30303827  COMPLETED          1        1 2023-10-02T13:32:34 2023-10-02T13:34:13 2023-10-02T13:34:20            256                                                     \n           30303827.batch  COMPLETED          1        1 2023-10-02T13:34:13 2023-10-02T13:34:13 2023-10-02T13:34:20             25                      989K                      989K \n          30303827.extern  COMPLETED          1        1 2023-10-02T13:34:13 2023-10-02T13:34:13 2023-10-02T13:34:20            256                      706K                      706K \n','\n',char(10)));
INSERT INTO job_data VALUES(35,4,'a01o_20220401_fc0_1_POST','2023-10-02-13:34:32','2023-10-02-13:37:28',1696246472,1696246575,1696246575,'COMPLETED',2,1,'00:05','debug',257,'2022-04-01 00:00:00','POST','fc0',1,1,'MARENOSTRUM4',30303829,'',1,14,0.0,0.0,'a01o_20220401_fc0_1_POST.20231002133624.out','a01o_20220401_fc0_1_POST.20231002133624.err',2,'a01o_20220401_fc0_1_CLEAN',replace('                 30303829  COMPLETED          1        1 2023-10-02T13:34:32 2023-10-02T13:36:10 2023-10-02T13:36:16            257                                                     \n           30303829.batch  COMPLETED          1        1 2023-10-02T13:36:10 2023-10-02T13:36:10 2023-10-02T13:36:16             15                     1029K                     1029K \n          30303829.extern  COMPLETED          1        1 2023-10-02T13:36:10 2023-10-02T13:36:10 2023-10-02T13:36:16            257                      706K                      706K \n','\n',char(10)));
INSERT INTO job_data VALUES(36,4,'a01o_20220401_fc0_2_SIM','2023-10-02-13:34:32','2023-10-02-13:50:46',1696246472,1696246690,1696246690,'COMPLETED',2,1,'00:05','debug',281,'2022-04-01 00:00:00','SIM','fc0',2,0,'MARENOSTRUM4',30303830,'',1,14,0.0,0.0,'a01o_20220401_fc0_2_SIM.20231002133820.out','a01o_20220401_fc0_2_SIM.20231002133820.err',2,'a01o_20220401_fc0_2_POST',replace('                 30303830  COMPLETED          1        1 2023-10-02T13:34:32 2023-10-02T13:38:08 2023-10-02T13:38:12            281                                                     \n           30303830.batch  COMPLETED          1        1 2023-10-02T13:38:08 2023-10-02T13:38:08 2023-10-02T13:38:12             17                      976K                      976K \n          30303830.extern  COMPLETED          1        1 2023-10-02T13:38:08 2023-10-02T13:38:08 2023-10-02T13:38:12            281                      706K                      706K \n','\n',char(10)));
INSERT INTO job_data VALUES(37,4,'a01o_20220401_fc0_1_CLEAN','2023-10-02-13:36:29','2023-10-02-13:41:27',1696246589,1696246810,1696246810,'COMPLETED',2,1,'00:05','debug',282,'2022-04-01 00:00:00','CLEAN','fc0',1,1,'MARENOSTRUM4',30303834,'',1,14,0.0,0.0,'a01o_20220401_fc0_1_CLEAN.20231002134023.out','a01o_20220401_fc0_1_CLEAN.20231002134023.err',2,'',replace('                 30303834  COMPLETED          1        1 2023-10-02T13:36:29 2023-10-02T13:40:07 2023-10-02T13:40:12            282                                                     \n           30303834.batch  COMPLETED          1        1 2023-10-02T13:40:07 2023-10-02T13:40:07 2023-10-02T13:40:12             24                     1036K                     1036K \n          30303834.extern  COMPLETED          1        1 2023-10-02T13:40:07 2023-10-02T13:40:07 2023-10-02T13:40:12            282                      704K                      704K \n','\n',char(10)));
INSERT INTO job_data VALUES(38,4,'a01o_20220401_fc0_2_POST','2023-10-02-13:38:25','2023-10-02-13:43:52',1696246705,1696246928,1696246969,'FAILED',2,1,'00:05','debug',303,'2022-04-01 00:00:00','POST','fc0',2,1,'MARENOSTRUM4',30303838,'',1,14,0.0,0.0,'a01o_20220401_fc0_2_POST.20231002134249.out','a01o_20220401_fc0_2_POST.20231002134249.err',2,'a01o_20220401_fc0_2_CLEAN',replace('                 30303838     FAILED          1        1 2023-10-02T13:38:25 2023-10-02T13:42:05 2023-10-02T13:42:09            303                                                     \n           30303838.batch     FAILED          1        1 2023-10-02T13:42:05 2023-10-02T13:42:05 2023-10-02T13:42:09             16                      983K                      983K \n          30303838.extern  COMPLETED          1        1 2023-10-02T13:42:05 2023-10-02T13:42:05 2023-10-02T13:42:09            303                      704K                      704K \n','\n',char(10)));
INSERT INTO job_data VALUES(39,5,'a01o_LOCAL_SETUP','2023-10-02-13:45:09','2023-10-02-13:45:58',1696247109,0,0,'SUBMITTED',2,1,'00:00','debug',0,'','LOCAL_SETUP','',0,0,'LOCAL',32570,'',0,15,0.0,0.0,'','',0,'a01o_SYNCHRONIZE','');
INSERT INTO job_data VALUES(40,6,'a01o_LOCAL_SETUP','2023-10-02-13:45:58','2023-10-02-13:46:16',1696247158,0,0,'SUBMITTED',2,1,'00:00','debug',0,'','LOCAL_SETUP','',0,0,'LOCAL',32720,'',0,17,0.0,0.0,'','',0,'a01o_SYNCHRONIZE','');
INSERT INTO job_data VALUES(41,7,'a01o_LOCAL_SETUP','2023-10-02-13:46:16','2023-10-02-13:46:29',1696247176,1696247176,1696247176,'COMPLETED',2,1,'00:00','debug',0,'','LOCAL_SETUP','',0,1,'LOCAL',32814,'',0,19,0.0,0.0,'a01o_LOCAL_SETUP.20231002134629.out','a01o_LOCAL_SETUP.20231002134629.err',5,'a01o_SYNCHRONIZE','');
INSERT INTO job_data VALUES(42,7,'a01o_SYNCHRONIZE','2023-10-02-13:46:29','2023-10-02-13:46:41',1696247189,1696247189,1696247193,'COMPLETED',2,1,'00:00','debug',0,'','SYNCHRONIZE','',0,1,'LOCAL',32860,'',0,19,0.0,0.0,'a01o_SYNCHRONIZE.20231002134641.out','a01o_SYNCHRONIZE.20231002134641.err',5,'a01o_REMOTE_SETUP','');
INSERT INTO job_data VALUES(43,7,'a01o_REMOTE_SETUP','2023-10-02-13:46:46','2023-10-02-13:50:03',1696247206,1696247290,1696247290,'COMPLETED',2,1,'00:05','debug',273,'','REMOTE_SETUP','',0,1,'MARENOSTRUM4',30303880,'',1,19,0.0,0.0,'a01o_REMOTE_SETUP.20231002134828.out','a01o_REMOTE_SETUP.20231002134828.err',2,'a01o_20220401_fc0_INI',replace('                 30303880  COMPLETED          1        1 2023-10-02T13:46:46 2023-10-02T13:48:05 2023-10-02T13:48:11            273                                                     \n           30303880.batch  COMPLETED          1        1 2023-10-02T13:48:05 2023-10-02T13:48:05 2023-10-02T13:48:11             53                     1011K                     1011K \n          30303880.extern  COMPLETED          1        1 2023-10-02T13:48:05 2023-10-02T13:48:05 2023-10-02T13:48:11            273                      704K                      704K \n','\n',char(10)));
INSERT INTO job_data VALUES(44,7,'a01o_20220401_fc0_INI','2023-10-02-13:48:34','2023-10-02-13:51:44',1696247314,1696247410,1696247410,'COMPLETED',2,1,'00:05','debug',235,'2022-04-01 00:00:00','INI','fc0',0,1,'MARENOSTRUM4',30304016,'',1,19,0.0,0.0,'a01o_20220401_fc0_INI.20231002135038.out','a01o_20220401_fc0_INI.20231002135038.err',2,'a01o_20220401_fc0_2_SIM,a01o_20220401_fc0_1_SIM',replace('                 30304016  COMPLETED          1        1 2023-10-02T13:48:34 2023-10-02T13:50:05 2023-10-02T13:50:12            235                                                     \n           30304016.batch  COMPLETED          1        1 2023-10-02T13:50:05 2023-10-02T13:50:05 2023-10-02T13:50:12             22                     1134K                     1134K \n          30304016.extern  COMPLETED          1        1 2023-10-02T13:50:05 2023-10-02T13:50:05 2023-10-02T13:50:12            235                      704K                      704K \n','\n',char(10)));
INSERT INTO job_data VALUES(45,7,'a01o_20220401_fc0_1_SIM','2023-10-02-13:50:46','2023-10-02-13:53:33',1696247446,1696247527,1696247527,'COMPLETED',2,1,'00:05','debug',295,'2022-04-01 00:00:00','SIM','fc0',1,1,'MARENOSTRUM4',30304177,'',1,19,0.0,0.0,'a01o_20220401_fc0_1_SIM.20231002135229.out','a01o_20220401_fc0_1_SIM.20231002135229.err',2,'a01o_POST',replace('                 30304177  COMPLETED          1        1 2023-10-02T13:50:46 2023-10-02T13:52:04 2023-10-02T13:52:09            295                                                     \n           30304177.batch  COMPLETED          1        1 2023-10-02T13:52:04 2023-10-02T13:52:04 2023-10-02T13:52:09             29                      967K                      967K \n          30304177.extern  COMPLETED          1        1 2023-10-02T13:52:04 2023-10-02T13:52:04 2023-10-02T13:52:09            295                      704K                      704K \n','\n',char(10)));
INSERT INTO job_data VALUES(46,7,'a01o_20220401_fc0_2_SIM','2023-10-02-13:50:46','2023-10-02-13:55:22',1696247446,1696247645,1696247645,'COMPLETED',2,1,'00:05','debug',231,'2022-04-01 00:00:00','SIM','fc0',2,1,'MARENOSTRUM4',30304178,'',1,19,0.0,0.0,'a01o_20220401_fc0_2_SIM.20231002135418.out','a01o_20220401_fc0_2_SIM.20231002135418.err',2,'a01o_POST',replace('                 30304178  COMPLETED          1        1 2023-10-02T13:50:46 2023-10-02T13:54:04 2023-10-02T13:54:06            231                                                     \n           30304178.batch  COMPLETED          1        1 2023-10-02T13:54:04 2023-10-02T13:54:04 2023-10-02T13:54:06             33                     1127K                     1127K \n          30304178.extern  COMPLETED          1        1 2023-10-02T13:54:04 2023-10-02T13:54:04 2023-10-02T13:54:06            231                      706K                      706K \n','\n',char(10)));
INSERT INTO job_data VALUES(47,7,'a01o_POST','2023-10-02-13:54:21','2023-10-02-13:57:33',1696247661,1696247770,1696247770,'COMPLETED',2,1,'00:05','debug',289,'','POST','',0,1,'MARENOSTRUM4',30304213,'',1,19,0.0,0.0,'a01o_POST.20231002135611.out','a01o_POST.20231002135611.err',2,'a01o_CLEAN',replace('                 30304213  COMPLETED          1        1 2023-10-02T13:54:21 2023-10-02T13:56:08 2023-10-02T13:56:12            289                                                     \n           30304213.batch  COMPLETED          1        1 2023-10-02T13:56:08 2023-10-02T13:56:08 2023-10-02T13:56:12             14                      980K                      980K \n          30304213.extern  COMPLETED          1        1 2023-10-02T13:56:08 2023-10-02T13:56:08 2023-10-02T13:56:12            289                      706K                      706K \n','\n',char(10)));
INSERT INTO job_data VALUES(48,7,'a01o_CLEAN','2023-10-02-13:56:34','2023-10-02-13:59:25',1696247794,1696247894,1696247894,'COMPLETED',2,1,'00:05','debug',308,'','CLEAN','',0,1,'MARENOSTRUM4',30304243,'',1,19,0.0,0.0,'a01o_CLEAN.20231002135822.out','a01o_CLEAN.20231002135822.err',2,'',replace('                 30304243  COMPLETED          1        1 2023-10-02T13:56:34 2023-10-02T13:58:10 2023-10-02T13:58:16            308                                                     \n           30304243.batch  COMPLETED          1        1 2023-10-02T13:58:10 2023-10-02T13:58:10 2023-10-02T13:58:16             26                     1035K                     1035K \n          30304243.extern  COMPLETED          1        1 2023-10-02T13:58:10 2023-10-02T13:58:10 2023-10-02T13:58:16            308                      704K                      704K \n','\n',char(10)));
DELETE FROM sqlite_sequence;
INSERT INTO sqlite_sequence VALUES('experiment_run',20);
INSERT INTO sqlite_sequence VALUES('job_data',48);
CREATE INDEX ID_JOB_NAME ON job_data(job_name);
COMMIT;
